# === GLOBAL MACROS ===========================================================

%global _hardened_build 1

# Mageia specific scriplet:
%define _mypost_service() /sbin/chkconfig --add %{1};

%global shared_requirements \
Requires:         bash                       \
Requires:         filesystem          >= 2   \
Requires:         coreutils                  \
Requires:         gawk                       \

# =============================================================================

Name:             initscripts
Summary:          Basic support for legacy System V init scripts
Version:          10.04
Release:          %mkrel 9

License:          GPLv2
Group:            System/Base

URL:              https://github.com/fedora-sysv/initscripts
Source:           https://github.com/fedora-sysv/initscripts/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:          %name-%version-mageia.tar.xz

# === PATCHES =================================================================

# To modify/see the source, mgaconf super patch and other patches
# please read:
# https://gitweb.mageia.org/software/forks/initscripts/tree/README.md?h=distro/mga

Patch1:           %name-%version-mageia.patch

%shared_requirements

Requires:         findutils
Requires:         grep
Requires:         procps-ng
Requires:         setup
Requires:         systemd
Requires:         util-linux

# (ovitters)  Due to urpmi not liking multiple packages obsoleting one package,
#             I'm requiring all the various other packages here. As a result
#             the various other packages are NOT optional. But this has the benefit
#             of making it easier to see the differences of this spec file vs
#             the Fedora one
Requires:         network-scripts
Requires:         netconsole-service
Requires:         readonly-root
Requires:         partmon

Requires(pre):    shadow-utils
Requires(posttrans):   coreutils

BuildRequires:    filesystem          >= 2
BuildRequires:    gcc
BuildRequires:    git
BuildRequires:    gettext
BuildRequires:    glib2-devel
BuildRequires:    pkgconfig
BuildRequires:    popt-devel
BuildRequires:    setup

%{?systemd_requires}
BuildRequires:    systemd

Provides:         /sbin/service

# (ovitters) urpmi does not like this, so instead the main package just requires all subpackages
#Obsoletes:        %%{name}            < 9.82-2

%description
This package provides basic support for legacy System V init scripts, and some
other legacy tools & utilities.

# === SUBPACKAGES =============================================================

%package -n network-scripts
Summary:          Legacy scripts for manipulating of network devices
Requires:         %{name}%{?_isa} = %{version}-%{release}

%shared_requirements

Requires:         bc
Requires:         dbus
Requires:         gawk
Requires:         grep
Requires:         hostname
Requires:         iproute2
Requires:         ipcalc
Requires:         kmod
Requires:         procps-ng
Requires:         sed
Requires:         systemd

# Mageia change because scripts still seem to require this:
Requires:         ethtool
Requires:         ifplugd

Requires(post):   chkconfig
Requires(preun):  chkconfig

Requires(posttrans): chkconfig
Requires(postun): chkconfig

# (ovitters) urpmi does not like this, so instead the main package just requires all subpackages
#Obsoletes:        %%{name}            < 9.82-2

# Mageia specific:
Recommends:       dhcp-client

%description -n network-scripts
This package contains the legacy scripts for activating & deactivating of most
network interfaces. It also provides a legacy version of 'network' service.

The 'network' service is enabled by default after installation of this package,
and if the network-scripts are installed alongside NetworkManager, then the
ifup/ifdown commands from network-scripts take precedence over the ones provided
by NetworkManager.

If user has both network-scripts & NetworkManager installed, and wishes to
use ifup/ifdown from NetworkManager primarily, then they has to run command:
 $ update-alternatives --config ifup

Please note that running the command above will also disable the 'network'
service.

# ---------------

%package -n netconsole-service
Summary:          Service for initializing of network console logging
Requires:         %{name} = %{version}-%{release}
BuildArch:        noarch

%shared_requirements

# Mageia customization: glibc instead of glibc-common
Requires:         glibc
Requires:         iproute2
Requires:         iputils
Requires:         kmod
Requires:         sed
Requires:         util-linux

# (ovitters) urpmi does not like this, so instead the main package just requires all subpackages
#Obsoletes:        %%{name}            < 9.82-2

%description -n netconsole-service
This packages provides a 'netconsole' service for loading of netconsole kernel
module with the configured parameters. The netconsole kernel module itself then
allows logging of kernel messages over the network.

# ---------------

%package -n readonly-root
Summary:          Service for configuring read-only root support
Requires:         %{name} = %{version}-%{release}
BuildArch:        noarch

%shared_requirements

Requires:         cpio
Requires:         findutils
Requires:         hostname
Requires:         iproute2
Requires:         ipcalc
Requires:         util-linux

# (ovitters) urpmi does not like this, so instead the main package just requires all subpackages
#Obsoletes:        %%{name}            < 9.82-2

%description -n readonly-root
This package provides script & configuration file for setting up read-only root
support. Additional configuration is required after installation.

Please note that readonly-root package is considered deprecated with limited support.
Please use systemd-volatile-root functionality instead, if possible.

# ---------------

%package -n partmon
Summary:          Service for monitoring partition free space
Requires:         %{name} = %{version}-%{release}
BuildArch:        noarch

%shared_requirements

Requires:         perl-MDK-Common >= 1.0.1

# (ovitters) urpmi does not like this, so instead the main package just requires all subpackages
#Obsoletes:        %%{name}            < 9.82-2

%description -n partmon
This package provides script & configuration file for monitoring the free space
of partitions at boot.

# === BUILD INSTRUCTIONS ======================================================

%prep
%autosetup -S git -a 1

# ---------------

%build
%make_build PYTHON=%{__python3}

# ---------------

%install
%make_install

# Mageia specific: use forked gprintify to change initscripts (the spec-helper
# one does not work)
%{__python3} po-mageia/gprintify.py \
	$(find %{buildroot}/etc/rc.d -type f) \
	$(find %{buildroot}/sysconfig/network-scripts -type f) \
	$(find %{buildroot}%{_prefix}/libexec -type f)
export DONT_GPRINTIFY=1

# This installs the NLS language files:
%find_lang %{name}

%ifnarch s390 s390x
  rm -f %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/ifup-ctc
%endif

# Additional ways to access documentation:
install -m 0755 -d %{buildroot}%{_docdir}/network-scripts

ln -s  %{_docdir}/%{name}/sysconfig.txt   %{buildroot}%{_docdir}/network-scripts/
ln -sr %{buildroot}%{_mandir}/man8/ifup.8 %{buildroot}%{_mandir}/man8/ifdown.8

# We are now using alternatives approach to better co-exist with NetworkManager:
touch %{buildroot}%{_sbindir}/ifup
touch %{buildroot}%{_sbindir}/ifdown

# =============================================================================

# Mageia specific
# fix %%{_sysconfdir}/sysconfig/network-scripts/if{down,up}-* permissions
chmod 755 %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/if{down,up}-*

# create missing dir (mga#29671)
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/wireless.d/
chmod 755 %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/wireless.d/

# (cg) Clean up danging symlinks after initscript removal
%transfiletriggerpostun -- %{_initrddir}/
find -L /etc/rc.d/rc{0,1,2,3,4,5,6,7}.d -type l -delete

# ---------------

# Mageia specific:
# (ovitters) avoid enabling services after split of services
%triggerin -- %{name} < 9.82-2
mkdir -p "%{_localstatedir}/lib/rpm-state/%{name}.notinstall" 2> /dev/null || :
mkdir -p "%{_localstatedir}/lib/rpm-state/network-scripts.notinstall" 2> /dev/null || :
mkdir -p "%{_localstatedir}/lib/rpm-state/netconsole-service.notinstall" 2> /dev/null || :
mkdir -p "%{_localstatedir}/lib/rpm-state/partmon.notinstall" 2> /dev/null || :
mkdir -p "%{_localstatedir}/lib/rpm-state/readonly-root.notinstall" 2> /dev/null || :

# ---------------

%post
# (ovitters) remember $1 for usage in posttrans scriptlet as posttrans always
# sets $1 to 1. See see https://bugs.mageia.org/show_bug.cgi?id=19882 and the
# comment in posttrans scriplet
#
# Note: Logic is a bit weird to avoid a dependency on mkdir. The 'mkdir'
# command might not exist in the install case. On upgrade the system will have·
# 'mkdir'. So basically this post scriptlet tells posttrans not to run the
# 'install' logic.
#
# WARNING: Do NOT add a Requires(post) on coreutils! Might cause dependency
# loops (see above bug for detailed discussion
if [ "$1" -ne 1 ]; then
# ignore "mkdir" not found errors
  mkdir -p "%{_localstatedir}/lib/rpm-state/%{name}.notinstall" 2> /dev/null || :
fi

%posttrans
# (ovitters) The posttrans scriptlet always has $1 to 1. This confuses:
# 1. The systemd_post scriplet (makes use of $1).
# 2. Any usage of $1 in posttrans (was used to not call chkconfig)
#
# systemd_post scriptlet only does something when the rpm is installed.·
# Make use of that knowledge to only call these scriptlets when this package is
# first installed. See https://bugs.mageia.org/show_bug.cgi?id=19882
if [ ! -d "%{_localstatedir}/lib/rpm-state/%{name}.notinstall" ]; then
  %systemd_post import-state.service loadmodules.service
  # Mageia specific services:
  %systemd_post mandriva-save-dmesg.service mandriva-everytime.service
  # reset the state
  rmdir "%{_localstatedir}/lib/rpm-state/%{name}.notinstall" 2> /dev/null || :
fi


%preun
%systemd_preun import-state.service loadmodules.service
%systemd_preun mandriva-save-dmesg.service mandriva-everytime.service

%postun
%systemd_postun import-state.service loadmodules.service
%systemd_postun mandriva-save-dmesg.service mandriva-everytime.service

# ---------------

%post -n network-scripts
# (ovitters) remember $1 for usage in posttrans scriptlet as posttrans always
# sets $1 to 1. See see https://bugs.mageia.org/show_bug.cgi?id=19882 and the
# comment in posttrans scriplet
#
# Note: Logic is a bit weird to avoid a dependency on mkdir. The 'mkdir'
# command might not exist in the install case. On upgrade the system will have·
# 'mkdir'. So basically this post scriptlet tells posttrans not to run the
# 'install' logic.
#
# WARNING: Do NOT add a Requires(post) on coreutils! Might cause dependency
# loops (see above bug for detailed discussion
if [ "$1" -ne 1 ]; then
# ignore "mkdir" not found errors
  mkdir -p "%{_localstatedir}/lib/rpm-state/network-scripts.notinstall" 2> /dev/null || :
fi

%posttrans -n network-scripts
# (ovitters) The posttrans scriptlet always has $1 to 1. This confuses:
# 1. The systemd_post scriplet (makes use of $1).
# 2. Any usage of $1 in posttrans (was used to not call chkconfig)
#
# systemd_post scriptlet only does something when the rpm is installed.·
# Make use of that knowledge to only call these scriptlets when this package is
# first installed. See https://bugs.mageia.org/show_bug.cgi?id=19882
if [ ! -d "%{_localstatedir}/lib/rpm-state/network-scripts.notinstall" ]; then
  chkconfig --add network > /dev/null 2>&1 || :
  # Mageia specific (network-up)
  chkconfig --add network-up > /dev/null 2>&1 || :
  # reset the state
  rmdir "%{_localstatedir}/lib/rpm-state/network-scripts.notinstall" 2> /dev/null || :
fi

[ -L %{_sbindir}/ifup ]   || rm -f %{_sbindir}/ifup
[ -L %{_sbindir}/ifdown ] || rm -f %{_sbindir}/ifdown

%{_sbindir}/update-alternatives --install %{_sbindir}/ifup   ifup   %{_sysconfdir}/sysconfig/network-scripts/ifup 90 \
                                --slave   %{_sbindir}/ifdown ifdown %{_sysconfdir}/sysconfig/network-scripts/ifdown \
                                --initscript network

%preun -n network-scripts
if [ $1 -eq 0 ]; then
  chkconfig --del network > /dev/null 2>&1 || :
  # Mageia specific (network-up):
  chkconfig --del network-up > /dev/null 2>&1 || :
  %{_sbindir}/update-alternatives --remove ifup %{_sysconfdir}/sysconfig/network-scripts/ifup
fi

# ---------------

%post -n netconsole-service
# (ovitters) remember $1 for usage in posttrans scriptlet as posttrans always
# sets $1 to 1. See see https://bugs.mageia.org/show_bug.cgi?id=19882 and the
# comment in posttrans scriplet
#
# Note: Logic is a bit weird to avoid a dependency on mkdir. The 'mkdir'
# command might not exist in the install case. On upgrade the system will have·
# 'mkdir'. So basically this post scriptlet tells posttrans not to run the
# 'install' logic.
#
# WARNING: Do NOT add a Requires(post) on coreutils! Might cause dependency
# loops (see above bug for detailed discussion
if [ "$1" -ne 1 ]; then
# ignore "mkdir" not found errors
  mkdir -p "%{_localstatedir}/lib/rpm-state/netconsole-service.notinstall" 2> /dev/null || :
fi

%posttrans -n netconsole-service
# (ovitters) The posttrans scriptlet always has $1 to 1. This confuses:
# 1. The systemd_post scriplet (makes use of $1).
# 2. Any usage of $1 in posttrans (was used to not call chkconfig)
#
# systemd_post scriptlet only does something when the rpm is installed.·
# Make use of that knowledge to only call these scriptlets when this package is
# first installed. See https://bugs.mageia.org/show_bug.cgi?id=19882
if [ ! -d "%{_localstatedir}/lib/rpm-state/netconsole-service.notinstall" ]; then
  %systemd_post netconsole.service
  # reset the state
  rmdir "%{_localstatedir}/lib/rpm-state/netconsole-service.notinstall" 2> /dev/null || :
fi

%preun -n netconsole-service
%systemd_preun netconsole.service

%postun -n netconsole-service
%systemd_postun netconsole.service

# ---------------

%post -n readonly-root
# (ovitters) remember $1 for usage in posttrans scriptlet as posttrans always
# sets $1 to 1. See see https://bugs.mageia.org/show_bug.cgi?id=19882 and the
# comment in posttrans scriplet
#
# Note: Logic is a bit weird to avoid a dependency on mkdir. The 'mkdir'
# command might not exist in the install case. On upgrade the system will have·
# 'mkdir'. So basically this post scriptlet tells posttrans not to run the
# 'install' logic.
#
# WARNING: Do NOT add a Requires(post) on coreutils! Might cause dependency
# loops (see above bug for detailed discussion
if [ "$1" -ne 1 ]; then
# ignore "mkdir" not found errors
  mkdir -p "%{_localstatedir}/lib/rpm-state/readonly-root.notinstall" 2> /dev/null || :
fi

%posttrans -n readonly-root
# (ovitters) The posttrans scriptlet always has $1 to 1. This confuses:
# 1. The systemd_post scriplet (makes use of $1).
# 2. Any usage of $1 in posttrans (was used to not call chkconfig)
#
# systemd_post scriptlet only does something when the rpm is installed.·
# Make use of that knowledge to only call these scriptlets when this package is
# first installed. See https://bugs.mageia.org/show_bug.cgi?id=19882
if [ ! -d "%{_localstatedir}/lib/rpm-state/readonly-root.notinstall" ]; then
  %systemd_post readonly-root.service
  # reset the state
  rmdir "%{_localstatedir}/lib/rpm-state/readonly-root.notinstall" 2> /dev/null || :
fi

%preun -n readonly-root
%systemd_preun readonly-root.service

%postun -n readonly-root
%systemd_postun readonly-root.service

# ---------------

%post -n partmon
# (ovitters) remember $1 for usage in posttrans scriptlet as posttrans always
# sets $1 to 1. See see https://bugs.mageia.org/show_bug.cgi?id=19882 and the
# comment in posttrans scriplet
#
# Note: Logic is a bit weird to avoid a dependency on mkdir. The 'mkdir'
# command might not exist in the install case. On upgrade the system will have·
# 'mkdir'. So basically this post scriptlet tells posttrans not to run the
# 'install' logic.
#
# WARNING: Do NOT add a Requires(post) on coreutils! Might cause dependency
# loops (see above bug for detailed discussion
if [ "$1" -ne 1 ]; then
# ignore "mkdir" not found errors
  mkdir -p "%{_localstatedir}/lib/rpm-state/partmon.notinstall" 2> /dev/null || :
fi

%posttrans -n partmon
# (ovitters) The posttrans scriptlet always has $1 to 1. This confuses:
# 1. The systemd_post scriplet (makes use of $1).
# 2. Any usage of $1 in posttrans (was used to not call chkconfig)
#
# systemd_post scriptlet only does something when the rpm is installed.·
# Make use of that knowledge to only call these scriptlets when this package is
# first installed. See https://bugs.mageia.org/show_bug.cgi?id=19882
if [ ! -d "%{_localstatedir}/lib/rpm-state/partmon.notinstall" ]; then
  %_mypost_service partmon
  # reset the state
  rmdir "%{_localstatedir}/lib/rpm-state/partmon.notinstall" 2> /dev/null || :
fi

%preun -n partmon
%_preun_service partmon

# === PACKAGING INSTRUCTIONS ==================================================

%files -f %{name}.lang
%license COPYING
%doc doc/sysconfig.txt

# NOTE: /etc/profile.d/ is owned by setup package.
#       /etc/sysconfig/ is owned by filesystem package.
%dir %{_sysconfdir}/rc.d
%dir %{_sysconfdir}/rc.d/init.d
%dir %{_sysconfdir}/rc.d/rc[0-6].d
%dir %{_sysconfdir}/sysconfig/console
%dir %{_sysconfdir}/sysconfig/modules
%dir %{_libexecdir}/%{name}
%dir %{_libexecdir}/%{name}/legacy-actions

# ---------------

%{_sysconfdir}/rc.d/init.d/functions

# RC symlinks:
%{_sysconfdir}/rc[0-6].d

%{_sysconfdir}/init.d

# ---------------

%attr(0755,root,root) %{_bindir}/listhome
%{_bindir}/usleep

%{_sbindir}/consoletype
%{_sbindir}/genhostid
%{_sbindir}/service

%{_libexecdir}/import-state
%{_libexecdir}/loadmodules

%{_prefix}/lib/systemd/system/import-state.service
%{_prefix}/lib/systemd/system/loadmodules.service
%{_prefix}/lib/udev/rename_device

%{_udevrulesdir}/*

%{_mandir}/man1/*
%{_mandir}/man8/service.*

# Mageia-specific:
%config(noreplace) /etc/modules
   /etc/sysconfig/autofsck

/etc/rc.modules
# hibernate-cleanup.sh: obsolete/unneeded?
%{_sbindir}/hibernate-cleanup.sh
%{_prefix}/lib/lsb/lsb-init-functions
%{_prefix}/lib/systemd/system/mandriva-everytime.service
%{_prefix}/lib/systemd/system/mandriva-save-dmesg.service
%{_libexecdir}/mageia-save-dmesg
%{_libexecdir}/mageia_everytime
%{_tmpfilesdir}/mageia.conf
%{_sysconfdir}/profile.d/*inputrc.*sh
%{_sysconfdir}/profile.d/*tmpdir.*sh
%{_sysconfdir}/profile.d/lang.*sh
%lang(cs)     %{_mandir}/cs/man*/*
%lang(et)     %{_mandir}/et/man*/*
%lang(fr)     %{_mandir}/fr/man*/*
%lang(it)     %{_mandir}/it/man*/*
%lang(pt_BR)  %{_mandir}/pt_BR/man*/*
%lang(ru)     %{_mandir}/ru/man*/*
%lang(uk)     %{_mandir}/uk/man*/*


# =============================================================================

%files -n network-scripts
%doc doc/examples/
%dir %{_sysconfdir}/sysconfig/network-scripts

%{_sysconfdir}/rc.d/init.d/network
%{_sysconfdir}/sysconfig/network-scripts/cellular.d
%{_sysconfdir}/sysconfig/network-scripts/hostname.d
%{_sysconfdir}/sysconfig/network-scripts/ifdown*
%{_sysconfdir}/sysconfig/network-scripts/ifup*
%{_sysconfdir}/sysconfig/network-scripts/init*
%{_sysconfdir}/sysconfig/network-scripts/network-functions*
%{_sysconfdir}/sysconfig/network-scripts/vpn.d
%{_sysconfdir}/sysconfig/network-scripts/wireless.d

%config(noreplace)    %{_sysconfdir}/sysconfig/network-scripts/ifcfg-lo

%ghost                %{_sbindir}/ifup
%ghost                %{_sbindir}/ifdown
%attr(4755,root,root) %{_sbindir}/usernetctl

%{_mandir}/man8/ifup.*
%{_mandir}/man8/ifdown.*
%{_mandir}/man8/usernetctl.*
%{_docdir}/network-scripts/*

# Mageia-specific:
%{_sbindir}/mdv-network-event
%{_sbindir}/vpn-{start,stop}
%{_sysconfdir}/rc.d/init.d/network-auth
%{_sysconfdir}/rc.d/init.d/network-up


# ---------------

%files -n netconsole-service
%config(noreplace) %{_sysconfdir}/sysconfig/netconsole

%{_libexecdir}/netconsole
%{_prefix}/lib/systemd/system/netconsole.service

# ---------------

%files -n readonly-root
%dir %{_sharedstatedir}/stateless
%dir %{_sharedstatedir}/stateless/state
%dir %{_sharedstatedir}/stateless/writable

%config(noreplace) %{_sysconfdir}/rwtab
%config(noreplace) %{_sysconfdir}/statetab
%config(noreplace) %{_sysconfdir}/sysconfig/readonly-root

%{_libexecdir}/readonly-root
%{_prefix}/lib/systemd/system/readonly-root.service

# ---------------

%files -n partmon
%config(noreplace) /etc/sysconfig/partmon
%{_sysconfdir}/rc.d/init.d/partmon
%attr(0755,root,root) %{_bindir}/partmon


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 10.04-9.mga10
+ Revision: 2221926
- Mageia 10 Mass Rebuild

* Fri Apr 05 2024 wally <wally> 10.04-8.mga10
+ Revision: 2054624
- basesystem rebuild for i686

* Sat Aug 19 2023 tmb <tmb> 10.04-7.mga9
+ Revision: 1964883
- revert change of default DHCP client to dhcpcd (mga#30938)

* Sat Jun 24 2023 martinw <martinw> 10.04-6.mga9
+ Revision: 1962941
- recommmend dhcpcd instead of dhcp-client (mga#30938)

* Wed May 03 2023 daviddavid <daviddavid> 10.04-5.mga9
+ Revision: 1955712
- use grep -E instead of deprecated egrep (mga#31662#c5)

* Sat Mar 18 2023 daviddavid <daviddavid> 10.04-4.mga9
+ Revision: 1949626
- fix dangling links:
  /usr/share/doc/network-scripts/sysconfig.txt -> ../../../../home/iurt/rpmbuild/
  BUILDROOT/initscripts-10.04-3.mga9.x86_64/usr/share/doc/initscripts/sysconfig.txt

* Fri Jan 06 2023 ghibo <ghibo> 10.04-3.mga9
+ Revision: 1930716
- Fix /usr/bin/partmon permission from 644 to 755.
- Fix /usr/bin/listhome permission from 644 to 755.

* Thu Mar 24 2022 umeabot <umeabot> 10.04-2.mga9
+ Revision: 1824557
- Mageia 9 Mass Rebuild

* Sat Nov 20 2021 wally <wally> 10.04-1.mga9
+ Revision: 1758120
- install missing /etc/sysconfig/network-scripts/wireless.d (mga#29671)

* Sun Oct 24 2021 wally <wally> 10.04-0.3.mga9
+ Revision: 1752786
- network-scripts: fix ifdown-* and ifup-* script permissions (mga#29581)

* Sun Oct 24 2021 wally <wally> 10.04-0.2.mga9
+ Revision: 1752782
- make network-scripts to require ifplugd (mga#29582)

* Thu Oct 14 2021 ovitters <ovitters> 10.04-0.1.mga9
+ Revision: 1751416
- avoid having multiple packages obsolete the same main package

* Mon Aug 17 2020 ovitters <ovitters> 10.04-0.1.mga8
+ Revision: 1614631
- prevent re-enabling services after package split
- test version 0.1
- update patch with latest changes
- new version 10.04

* Mon Aug 03 2020 ovitters <ovitters> 9.78-27.mga8
+ Revision: 1610756
- move ownership of /var/log/{wtmp,btmp} from initscripts to systemd

* Sat Aug 01 2020 ovitters <ovitters> 9.78-26.mga8
+ Revision: 1610429
- move ownership of /etc/crypttab from initscripts to systemd

* Fri Jul 31 2020 ovitters <ovitters> 9.78-25.mga8
+ Revision: 1610013
- /etc/{rwtab.d,statetab.d} dir ownership moved to filesystem package

* Wed Jul 29 2020 ovitters <ovitters> 9.78-24.mga8
+ Revision: 1609564
- networks: moved to setup package

* Tue Jul 28 2020 ovitters <ovitters> 9.78-23.mga8
+ Revision: 1609462
- adjtime: moved to util-linux
- /etc/{rwtab.d,statetab.d}: move back as filesystem package does not upload atm

* Tue Jul 28 2020 ovitters <ovitters> 9.78-22.mga8
+ Revision: 1609456
- move ownership of /etc/{rwtab.d,statetab.d} to filesystem package

* Tue Jul 28 2020 ovitters <ovitters> 9.78-21.mga8
+ Revision: 1609430
- move fedora-domainname to hostname package (as nis-domainname)

* Mon Jul 27 2020 ovitters <ovitters> 9.78-20.mga8
+ Revision: 1609313
- fix error in posttrans scriplet due to a missing space

* Mon Jul 27 2020 ovitters <ovitters> 9.78-19.mga8
+ Revision: 1609282
- ensure systemd_post and _mypost_service are only called on installation (mga#19882)
- remove fork ChangeLog file (removed from our fork)

* Sat Jul 25 2020 ovitters <ovitters> 9.78-18.mga8
+ Revision: 1609014
- service: fix the booted-with-systemd check

* Fri Jul 24 2020 ovitters <ovitters> 9.78-17.mga8
+ Revision: 1608858
- remove ancient and unneeded non-systemd udev rule which due to bug started giving errors (mga#26990)
- remove ancient code to change the sys5init partmon boot priority
- remove ancient /etc/sysconfig/desktop migration code
- remove preset transition

* Sun May 24 2020 wally <wally> 9.78-16.mga8
+ Revision: 1587207
- build with python3

* Tue May 12 2020 pterjan <pterjan> 9.78-15.mga8
+ Revision: 1583354
- Fix DHCPv6 support (mga#15157)

* Wed Feb 19 2020 umeabot <umeabot> 9.78-14.mga8
+ Revision: 1543469
- Mageia 8 Mass Rebuild

* Mon Jan 20 2020 eatdirt <eatdirt> 9.78-13.mga8
+ Revision: 1481748
- Fix change of the return value in grep preventing network interface to start

* Wed Oct 09 2019 tmb <tmb> 9.78-12.mga8
+ Revision: 1450886
- revert broken fix for mga#24525
  * fix was not added to mageia git
  * it broke several bits in /etc that has lang.sh hardcoded

* Mon Sep 23 2019 zezinho <zezinho> 9.78-11.mga8
+ Revision: 1444878
- apply mga6 change to fix mga#24525

* Fri Feb 15 2019 wally <wally> 9.78-10.mga7
+ Revision: 1367186
- replace /var/run with /run and /var/lock with /run/lock in systemd tmpfiles.d drop-in file

* Tue Oct 30 2018 martinw <martinw> 9.78-9.mga7
+ Revision: 1326572
- sdd [Install] sections to mandriva systemd service units

* Mon Sep 03 2018 tv <tv> 9.78-8.mga7
+ Revision: 1256729
- most all %%post to %%tranpost in order to ease rpm depsloops
- drop old provides on rhsound/sapinit
- drop old obsoletes
- drop no more needed requires on dmsetup

* Sun Sep 02 2018 rapsys <rapsys> 9.78-6.mga7
+ Revision: 1256316
- Fix tmout warning with resourcing of /etc/security/shell resourcing with SECSHELL variable

* Thu Jan 04 2018 ngompa <ngompa> 9.78-5.mga7
+ Revision: 1190074
- Ensure prefdm->dm unit transition occurs by forcibly enabling unit in trigger
- Refactor trigger to deduplicate the systemctl enable and message echo statements

* Mon Jan 01 2018 ngompa <ngompa> 9.78-4.mga7
+ Revision: 1188842
- Add fix from pterjan for ifup-eth merge error

* Sun Dec 31 2017 ngompa <ngompa> 9.78-3.mga7
+ Revision: 1188424
- Add kdm->sddm transition for default dm setting to transition scriptlet

* Sun Dec 31 2017 ngompa <ngompa> 9.78-2.mga7
+ Revision: 1188309
- Add transition scriptlet for prefdm->systemd unit preset

* Sat Dec 30 2017 ngompa <ngompa> 9.78-1.mga7
+ Revision: 1188129
- Rebase to v9.78
- Backport patch to drop prefdm
- Drop debugmode subpackage as upstream has done

* Wed Aug 02 2017 sander85 <sander85> 9.55-27.mga7
+ Revision: 1133921
- Try to fix mga#19882

* Mon Jul 31 2017 tv <tv> 9.55-26.mga7
+ Revision: 1132938
- revert blindly removing deps thus breaking partmon

* Sun Jul 30 2017 sander85 <sander85> 9.55-25.mga7
+ Revision: 1132926
- Drop deps on perl-MDK-Common (some other package should require it, if really needed)

* Tue Mar 14 2017 martinw <martinw> 9.55-24.mga6
+ Revision: 1092590
- Actually apply patch added in r905759 to remove call to dkms_autoinstaller
  from /etc/init.d/mandrake_everytime (mga#17194)
- Ensure mandiva-everytime service runs after dkms-autorebuild service to
  stop service_hardrake erroneously reconfiguring the system to use a free
  driver because dkms hasn't finished building the proprietary driver

* Mon Feb 27 2017 martinw <martinw> 9.55-23.mga6
+ Revision: 1088088
- prefdm: execute first-time actions when requested (mga#17223)
  This used to be performed during the selected DM startup, but
  but GDM and SDDM no longer provide the necessary hooks to run
  a user startup script.

* Thu Dec 01 2016 ghibo <ghibo> 9.55-22.mga6
+ Revision: 1071356
- Add latest check for quitting plymouth

* Sat Jul 23 2016 tmb <tmb> 9.55-21.mga6
+ Revision: 1043448
- set plymouth_quit flag for sddm

* Fri Jul 22 2016 tmb <tmb> 9.55-20.mga6
+ Revision: 1043079
- prefdm: kdm has been replaced by sddm
+ neoclust <neoclust>
- Revert to current cauldron version ( 9.55 ) as i never uploaded 9.66 in time
- New version 9.66

* Mon Jun 06 2016 tv <tv> 9.55-19.mga6
+ Revision: 1020430
- do not package huge & outdated ChangeLog-RH.gz

* Wed Jan 13 2016 tv <tv> 9.55-18.mga6
+ Revision: 922864
- fix deps loops with systemd: s/%%post/%%posttrans/

* Tue Nov 24 2015 doktor5000 <doktor5000> 9.55-17.mga6
+ Revision: 905759
- remove dkms_autoinstaller from /etc/init.d/mandrake_everytime (mga#17194)
  o split out into dkms-autorebuild.sh in dkms package

* Sun Oct 11 2015 wally <wally> 9.55-16.mga6
+ Revision: 889795
- add patch to drop non-working -H switch from dhclient cmd to get ipv6 address via dhcp

* Sun Sep 06 2015 tv <tv> 9.55-15.mga6
+ Revision: 873283
- submit to core/release

* Fri Aug 14 2015 tv <tv> 9.55-14.mga6
+ Revision: 864776
- use new rpm-4.13 filetriggers
- kill very old triggers (rpm-4.13 cries when there's "duplicate" ones)

* Fri Mar 06 2015 luigiwalser <luigiwalser> 9.55-13.mga5
+ Revision: 817956
- remove requires on prcsys, not used since the switch to systemd

* Wed Jan 14 2015 luigiwalser <luigiwalser> 9.55-12.mga5
+ Revision: 810713
- remove requires on mingetty, not needed since mga1 (we use agetty in util-linux)

* Mon Jan 12 2015 colin <colin> 9.55-11.mga5
+ Revision: 810149
- Fix minor problem with readonly roots fs + random-seed

* Sun Oct 19 2014 colin <colin> 9.55-10.mga5
+ Revision: 791623
- Kill off post actions for dm service. It's long gone.

* Wed Oct 15 2014 umeabot <umeabot> 9.55-9.mga5
+ Revision: 751120
- Second Mageia 5 Mass Rebuild

* Thu Oct 09 2014 tv <tv> 9.55-8.mga5
+ Revision: 737789
- add requires(pre) on systemd (fix one error in install)

* Tue Sep 16 2014 umeabot <umeabot> 9.55-7.mga5
+ Revision: 680514
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes
- s/uggests:/Recommends:/

* Thu Sep 11 2014 colin <colin> 9.55-6.mga5
+ Revision: 674722
- Kill off old, unused dm initscript
- Kill off speedboot stuff that was still lingering around
- Kill off supermount which is no longer used/working
- No longer rely on sysvinit-tools for pidof (it's in procps now)

* Thu Sep 11 2014 colin <colin> 9.55-5.mga5
+ Revision: 674699
- Restore old wireless init scripts (no time to convert properly) mga#14023
- Provide /sbin/service manually due to usrmove path updates mga#14087

* Tue Sep 09 2014 luigiwalser <luigiwalser> 9.55-4.mga5
+ Revision: 673849
- add requires on hostname now that it is in a different package

* Mon Sep 01 2014 colin <colin> 9.55-3.mga5
+ Revision: 670672
- Tidy up conflicts and remove older ppp conflict (replacing with newer one) mga#14024

* Sun Aug 31 2014 lmenut <lmenut> 9.55-2.mga5
+ Revision: 670044
- fix fedora-storage-init not executable

* Sat Aug 30 2014 colin <colin> 9.55-1.mga5
+ Revision: 669511
- New version: 9.55

* Mon Aug 04 2014 alien <alien> 9.41-23.mga5
+ Revision: 659611
- remove requirement to sound-scripts, since coling had removed the responsible scripts

* Wed Jul 23 2014 colin <colin> 9.41-22.mga5
+ Revision: 655934
- Fix for Network Manager API change.

* Wed Jan 22 2014 colin <colin> 9.41-21.mga4
+ Revision: 567390
- Drop support for GDM_LANG mga#12328

* Sat Dec 28 2013 colin <colin> 9.41-20.mga4
+ Revision: 562924
- Remove support for cleaning the (tmpfs) /tmp on every boot
- Ensure VPN network name is properly quoted (mga#10873)

* Tue Nov 05 2013 tmb <tmb> 9.41-19.mga4
+ Revision: 549609
- revert change to %%posttrans as it breaks activating of services at install time

* Thu Oct 31 2013 tmb <tmb> 9.41-18.mga4
+ Revision: 548701
- switch from %%post to %%posttrans to help with deps ordering

* Sat Oct 19 2013 umeabot <umeabot> 9.41-17.mga4
+ Revision: 531378
- Mageia 4 Mass Rebuild

* Sun Aug 04 2013 colin <colin> 9.41-16.mga4
+ Revision: 463334
- Drop no longer needed mandriva-boot-links service/script

* Wed Jul 31 2013 colin <colin> 9.41-15.mga4
+ Revision: 461719
- Fix network-up ordering cycle with newer systemd
+ danf <danf>
- Reworked previous patch to completely fix backspace issue with csh (mga#5007)

* Wed May 08 2013 blino <blino> 9.41-14.mga3
+ Revision: 412606
- mdv-network-event: use mageia.org instead of mandriva.com in dbus events
  drakx-net is listening for events coming from mageia.org
  This should fix detection of connection success/failure in net_applet,
  draknetcenter and drakroam.

* Sun Mar 24 2013 colin <colin> 9.41-13.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Thu Mar 07 2013 dams <dams> 9.41-12.mga3
+ Revision: 401620
- fix Suggests about 'dhclient' ('dhcp-client' now) as spotted by leuhmanu

* Wed Feb 27 2013 colin <colin> 9.41-11.mga3
+ Revision: 400506
- Bail out of ifup/down if NM is used and we cannot find the UUID/device mga#9028
- Fix sysvinit symlink cleanup filter again (thanks to Dan Fandrich)
- Buildroot macro changes
- Quote the file name in the cleanup filter.
- Add a filetrigger to clean up broken sysvinit script links.
- Reapply csh backspace fix added by Remmy lost on mgaconf rebase (mga#5007)

* Mon Jan 14 2013 colin <colin> 9.41-9.mga3
+ Revision: 385734
- Drop inittab tweaks - no longer used.
- Do not ship files in /var/run

* Sat Jan 12 2013 umeabot <umeabot> 9.41-8.mga3
+ Revision: 354402
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 dams <dams> 9.41-7.mga3
+ Revision: 343918
- add 'dhclient' as a suggests (as explained on mageia-dev@)

* Sun Jan 06 2013 colin <colin> 9.41-6.mga3
+ Revision: 340048
- Don't mask errors from fedora-loadmodules.service (mga#8472)

* Sun Jan 06 2013 colin <colin> 9.41-5.mga3
+ Revision: 340017
- Wrap wireless patch into main mgaconf patch (mga#8343)
- Add simple fix to prevent exit status leakage (unlikely/rare in practice mga#7489)

* Sun Dec 23 2012 remmy <remmy> 9.41-4.mga3
+ Revision: 334192
+ rebuild (emptylog)

* Sun Dec 23 2012 remmy <remmy> 9.41-3.mga3
+ Revision: 334129
- No longer try to configure the backspace key for the C shell (closes mga#5007)

* Sun Dec 09 2012 tmb <tmb> 9.41-2.mga3
+ Revision: 329208
- add back check for wireless sysfs dir (P0, #8343)
+ colin <colin>
- Fix up paths and use nice dir macros where possible

* Tue Oct 30 2012 colin <colin> 9.41-1.mga3
+ Revision: 311597
- New version: 9.41
- Drop upstream cherry picks
- Remove the not-really-optional _with_systemd variable.
- Ship an empty /etc/crypttab (to shut up udisks2 mga#3661)

* Tue Oct 23 2012 blino <blino> 9.34-30.mga3
+ Revision: 309530
- drop patches merged in our git tree
- network-functions: fix detecting wireless devices in sysfs
  The wireless directory has been removed in kernel commit
  35b2a113cb0298d4f9a1263338b456094a414.
  Check the phy80211 symlink instead.

* Sun Oct 07 2012 tv <tv> 9.34-29.mga3
+ Revision: 303225
- fix conflicts with ppp (#7683)

* Sun Sep 02 2012 tv <tv> 9.34-28.mga3
+ Revision: 287219
- s/util-linux-ng/util-linux/
- mount requires is dup

* Tue Jul 24 2012 colin <colin> 9.34-27.mga3
+ Revision: 273996
- Rebuild with new spec-helper for non-relative symlnks to /dev/null

* Sun Jul 22 2012 blino <blino> 9.34-26.mga3
+ Revision: 273545
- remove mandriva-clean-var-run-lock systemd service, unneded now that
  /var/lock is a symlink to /run/lock
- inputrc:
  o do not export LESS=-MM anymore
    LESS=-MM breaks colorized output of git, and maybe perl-doc as well
    (Mdv #57143). It seems no other distro is shipping this as default,
    should be safe to remove.
  o do not export LESSKEY, less defaults to the same files already
  o do not export INPUTRC, readline defaults to the same files already
  o remove now unused inputrc.sh profile script

* Sun Jul 22 2012 colin <colin> 9.34-25.mga3
+ Revision: 273407
- Quick fix to prevent initscript trashing /var/{run,lock} symlinks

* Sat Jun 30 2012 colin <colin> 9.34-24.mga3
+ Revision: 265523
- Update for new udevd service name

* Tue Jun 12 2012 tv <tv> 9.34-23.mga3
+ Revision: 260098
- bump conflict with ppp

* Tue Jun 12 2012 tv <tv> 9.34-22.mga3
+ Revision: 259955
+ rebuild (emptylog)

* Sun Jun 10 2012 tv <tv> 9.34-21.mga3
+ Revision: 259274
- require kmod instead of module-init-tools

* Sat Apr 28 2012 tmb <tmb> 9.34-20.mga2
+ Revision: 233754
- Require rpm-helper >= 0.24.8-1 for systemd support

* Fri Apr 27 2012 colin <colin> 9.34-19.mga2
+ Revision: 233445
- Fix issue with nscd cache invalidating under systemd (mga#2707)

* Tue Apr 24 2012 colin <colin> 9.34-18.mga2
+ Revision: 233169
- Roll up mageia patches into mgaconf mega patch (no functional change)
- Fix issue where ifcfg-* files may have spaces in them (from NM)
- Prevent invalid failure code leaking from /etc/rc.modules

* Fri Apr 06 2012 colin <colin> 9.34-17.mga2
+ Revision: 229306
- Various cosmetic fixes to units/sysv scripts

* Fri Apr 06 2012 colin <colin> 9.34-16.mga2
+ Revision: 228889
- Prevent udev running network actions during early boot.

* Tue Apr 03 2012 colin <colin> 9.34-15.mga2
+ Revision: 228124
- Do not block systemctl requests run via harddrake on boot (mga#4772)

* Tue Apr 03 2012 colin <colin> 9.34-14.mga2
+ Revision: 227992
- Allow network manager to ignore unplugged/disabled devices during network-up.

* Sun Apr 01 2012 colin <colin> 9.34-13.mga2
+ Revision: 227663
- Mask netfs initscript under systemd (it has native support)
- Ensure that when network-auth sysvinit script is enabled, it holds up logins under system

* Mon Mar 26 2012 colin <colin> 9.34-12.mga2
+ Revision: 226507
- Ignore NetworkManager TYPE=Wireless ifcfg-* files in network-up too.
- Ignore TYPE=Wireless ifcfg files at shutdown too.
- Ensure NetworkManager is started before network script (if it's enabled) to prevent double control of interfaces

* Sat Mar 24 2012 colin <colin> 9.34-11.mga2
+ Revision: 226117
- Assume NetworkManager is used if NM_CONTROLLED is not false (as opposed to being true)
- Do per-device checks when working with NetworkManager
- Fix runlevel switching by preventing wiping out /var/run (mga#4744)
- Minor fixes to 'service' wrapper script

* Mon Mar 19 2012 colin <colin> 9.34-10.mga2
+ Revision: 223843
- Ignore network config scripts with TYPE=Wireless (from Network Manager)

* Sun Mar 11 2012 tmb <tmb> 9.34-9.mga2
+ Revision: 222825
- fix path to mdadm map (mga #4875)

* Thu Mar 08 2012 colin <colin> 9.34-8.mga2
+ Revision: 221746
- Adjust scripts for display manager failure message (mga#4769)

* Thu Mar 08 2012 colin <colin> 9.34-7.mga2
+ Revision: 221383
- Add some upstream cherry picks
- Add a fallback message when prefdm does not start a dm under systemd (mga#4769)
- Remove the inittab hacks for dm service (predates Mageia)

* Thu Mar 01 2012 colin <colin> 9.34-6.mga2
+ Revision: 216397
- Remove kdm plymouth hack (suspect it was other reasons causing problems)
- Add lxdm to the prefdm script

* Thu Feb 16 2012 dmorgan <dmorgan> 9.34-5.mga2
+ Revision: 209764
- Add a patch to workaround a kdm start issue

* Mon Jan 23 2012 tv <tv> 9.34-4.mga2
+ Revision: 200330
- drop suggests on wireless-tools & comgt that bring tcl in basesystem through
  usb_modeswitch which should be installed by drakx-net when needed
  let's unbloat basesystem
+ dmorgan <dmorgan>
- Fix URL

* Wed Dec 14 2011 colin <colin> 9.34-3.mga2
+ Revision: 181642
- Fix bug with sysvinit and timezones (mga#3512)

* Fri Nov 04 2011 colin <colin> 9.34-2.mga2
+ Revision: 162954
- Fix a script error in rc.sysinit.

* Fri Nov 04 2011 colin <colin> 9.34-1.mga2
+ Revision: 162695
- New version: 9.34
- Change how prefdm works to be more similar to Fedora (does not return)
- Merge all patches into the 'mdkconf' patch, but compress it and call it mgaconf

* Mon Oct 31 2011 colin <colin> 9.25-2.mga2
+ Revision: 160469
- Remove support for upstart. It's not packaged in Mageia, nor will it be.
- Change capitalisation of SysVinit require and unitfy versions with sysvinit-tools

* Sat Oct 29 2011 dmorgan <dmorgan> 9.25-1.mga2
+ Revision: 159653
- Rebuild to push in core media

* Sat Oct 22 2011 colin <colin> 9.25-0.3.mga2
+ Revision: 157407
- Update to 9.25
- Drop unneeded patches (e.g. no need to link to static glib as it's in /lib)
- Regenerate mdkconf from new Mageia initscripts git repo
- Move other patches to git and generate patchsets.
- Remove patch merged into previous mdkconf patch update.
+ dmorgan <dmorgan>
- More mandriva removal ( mga #1560)
- Remove some mandriva words ( mga #1527)

* Sat May 28 2011 blino <blino> 9.21-12.mga1
+ Revision: 100600
- run chvt with --userwait option at shutdown to avoid hanging waiting
  for chvt 1, since dm stop might have triggered a vt change as well
  details from vuntz on https://bugzilla.novell.com/show_bug.cgi?id=540482#c115
  (happens on my laptop with Mobility Radeon 9600 M10, plymouth disabled)

* Mon May 23 2011 pterjan <pterjan> 9.21-11.mga1
+ Revision: 100267
- Add patches from bug #1290 to fix plymouth password requests

* Thu May 12 2011 blino <blino> 9.21-10.mga1
+ Revision: 97422
- suggest wireless-tools and comgt

* Mon May 09 2011 tmb <tmb> 9.21-9.mga1
+ Revision: 96705
- add BR: glib2-static-devel
- replace file requires with proper package names
- drop buildroot
- drop rpm tags
- replace-LANG-with-LC_ALL so sed works correctly (#1216)

* Sun Apr 17 2011 anssi <anssi> 9.21-8.mga1
+ Revision: 87250
- Several bugfixes to speedboot:
  o In very early boot, call display_driver_helper to check if there is a
    pending dkms build (that may cause a wrong older binary dkms driver
    to be loaded by X server) or a conflicting driver loaded by initrd
    (which may cause graphical corruption / freeze when starting server)
    and disable speedboot in those cases.
  o Load display drivers before X when in speedboot.
  o In speedboot mode, reopen file descriptors after X should've started.
    This ensures that harddrake_service (and other sysinit output) is
    shown to the user if the X startup failed. (plymouth grabs the output,
    and when it shuts down the output is lost until descriptors are
    reopened).

* Thu Mar 31 2011 ahmad <ahmad> 9.21-7.mga1
+ Revision: 79281
- don't own /etc/sysconfig/, it's owned by filesystem rpm

* Thu Mar 24 2011 rtp <rtp> 9.21-6.mga1
+ Revision: 77151
- add -lrt as workaround for link failure
- Remove trailing slash at the end of TMPDIR/TMP

* Mon Feb 07 2011 rtp <rtp> 9.21-5.mga1
+ Revision: 48584
- Change system from Mandriva Linux to Mageia

* Mon Jan 24 2011 ennael <ennael> 9.21-4.mga1
+ Revision: 36784
- imported package initscripts


* Fri Dec 03 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 9.21-4mdv2011.0
+ Revision: 606521
- add conflict with systemd for smooth update
- remove shutdown services provided natively by systemd

* Wed Dec 01 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 9.21-3mdv2011.0
+ Revision: 604580
- fix sysinit.service not launched with systemd v15
- add prefdm alias back to dm.service

* Tue Nov 30 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 9.21-2mdv2011.0
+ Revision: 603785
- enable systemd units
  install prefdm.service as dm.service to hide initscript
- fix prefdm.service for Mandriva
- network-functions need not be %%config

* Sun Nov 28 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 9.21-1mdv2011.0
+ Revision: 602277
- merge 9.21
- do not unmount /proc in halt, it is not needed and confuses systemd
- use LC_ALL for nmcli output (we set LC_MESSAGES with overrides LANG)
- export INIT_VERSION in systemd units (patch from systemd)
- export SINGLE in single.service in case /etc/sysconfig/init was not
  updated (patch from systemd)
- conditional build systemd units (disabled for now)

* Wed Nov 17 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 9.17-1mdv2011.0
+ Revision: 598268
- sync with Fedora 9.17

  + Frederic Crozat <fcrozat@mandriva.com>
    - call chvt with --userwait to prevent deadlock at shutdown (Novell bug #540482)

* Wed Jun 23 2010 Frederic Crozat <fcrozat@mandriva.com> 8.99-15mdv2010.1
+ Revision: 548707
- Update translations

* Wed May 26 2010 Frederic Crozat <fcrozat@mandriva.com> 8.99-14mdv2010.1
+ Revision: 546243
- do not quit plymouth in runlevel 5, prefdm or gdm handles that (Mdv bug #59431)
- hide splash for luks passphrase, do not quit it
- do not call plymouth hide twice for Fsck
- update translations

* Wed May 19 2010 Frederic Crozat <fcrozat@mandriva.com> 8.99-13mdv2010.1
+ Revision: 545346
- Disable smooth X transition for KDE for now

* Wed May 05 2010 Frederic Crozat <fcrozat@mandriva.com> 8.99-12mdv2010.1
+ Revision: 542583
- Ensure prefdm and rc don't call plymouth quit for smooth plymouth => X transition

* Tue May 04 2010 Frederic Crozat <fcrozat@mandriva.com> 8.99-11mdv2010.1
+ Revision: 542072
- Updated translations
- add wait point for rc.modules in speedboot mode

* Thu Apr 22 2010 Frederic Crozat <fcrozat@mandriva.com> 8.99-10mdv2010.1
+ Revision: 537862
- ensure udev trigger is called with add action, default action will change in next udev releases

* Fri Feb 26 2010 Frederic Crozat <fcrozat@mandriva.com> 8.99-9mdv2010.1
+ Revision: 511930
- ensure loadkeys is really called in the right order (Mdv bug #57134)
- try to wake-up stopped process at shutdown (from Debian) (Mdv bug #57781)
- translations update

* Mon Feb 01 2010 Frederic Crozat <fcrozat@mandriva.com> 8.99-8mdv2010.1
+ Revision: 499120
- remove false check for volume saving on Mandriva (Mdv bug #57265)
- ensure dm-mod is loaded in speedboot mode too (Mdv bug #57351)
- Ensure loadkeys is called in sequence (Mdv bug #57134)

* Thu Jan 14 2010 Frederic Crozat <fcrozat@mandriva.com> 8.99-7mdv2010.1
+ Revision: 491529
- Fix obsolete syntax in udev rules file
- Restore old wireless behavior (revert bug #47791 fix and add fixes from
  bug #54002) (eugeni)
- Avoid 'no block devices found' message on boot when checking for dmraid
  (#55344) (eugeni)
- Update ifup script to properly work with new dhcpcd versions (#52673) (eugeni)
- Use correct address when waiting for network to be up (#56496) (eugeni)
- translation updates

* Tue Oct 27 2009 Eugeni Dodonov <eugeni@mandriva.com> 8.99-6mdv2010.0
+ Revision: 459539
- ensure wpa_supplicant is properly restarted (#54002)

* Thu Oct 22 2009 Eugeni Dodonov <eugeni@mandriva.com> 8.99-5mdv2010.0
+ Revision: 458941
- fix connecting to wireless networks after suspend/resume (#54002)
- try to load tun module when necessary (#54748)
- do not hardcode path to tunctl (#54740)
- translation updates

  + Frederic Crozat <fcrozat@mandriva.com>
    - Really put back hacks for unicode_start/stop and console font loading
    - update translations messages
    - Try to detect if /usr is not mounted yet when booting
    - udev failed events are now handled in udev-post
    - fix network link up detection (anssi, eugeni)
    - fix plymouth splash for crypto  (buchan)

* Fri Oct 16 2009 Frederic Crozat <fcrozat@mandriva.com> 8.99-3mdv2010.0
+ Revision: 457932
- Change keymaps and console fonts loading, use udev for most of it (like Fedora)
- failed udev events are now handled by udev-post, not rc.sysinit
- Plymouth startup / shutdown text are now translated (and different for shutdown / reboot)
- Remove leftover of splashy support
- Ensure /usr is mounted before showing plymouth prompt
- Unmount filesystems in reverse order (Eugeni, mdv bug #53042)
- Do not try to remove obsolete files in /tmp at startup
- do rtc init in first udev pass in speedboot mode
- various speed optimisations from upstream
- link udev help with glib statically, to reduce initrd size
- Fix "no raid disk" error at startup (GIT)

* Mon Oct 05 2009 Frederic Crozat <fcrozat@mandriva.com> 8.99-2mdv2010.0
+ Revision: 453964
- Fix hardware clock setting if hctosys is not available in sysfs
- Ensure killall return code is correctly handled in halt (Fedora)

* Fri Oct 02 2009 Frederic Crozat <fcrozat@mandriva.com> 8.99-1mdv2010.0
+ Revision: 452642
- Release 8.99 (resync with RH)
- Fix VT race preventing reboot (Mdv bug #53757)
- Save alsa levels in halt and not in alsa service anymore at shutdown
- do not wait 2s if not needed at shutdown

* Wed Sep 23 2009 Eugeni Dodonov <eugeni@mandriva.com> 8.97-11mdv2010.0
+ Revision: 447850
- Correctly wait for network to be up (#43654).

* Wed Sep 23 2009 Frederic Crozat <fcrozat@mandriva.com> 8.97-10mdv2010.0
+ Revision: 447746
- Ensure plymouth is terminated when using xdm/autologin
- Add signals for network status and properly select wpa_supplicant (Mdv bug #47791)

* Thu Sep 10 2009 Frederic Crozat <fcrozat@mandriva.com> 8.97-9mdv2010.0
+ Revision: 437109
- Ensure plymouth is terminated when running in single-user mode

* Tue Sep 01 2009 Frederic Crozat <fcrozat@mandriva.com> 8.97-8mdv2010.0
+ Revision: 423711
- Ensure password is correctly asked when splash is disabled (Mdv bug #53301)

* Wed Aug 26 2009 Frederic Crozat <fcrozat@mandriva.com> 8.97-7mdv2010.0
+ Revision: 421465
- Replace file dependencies with package dependencies

* Tue Aug 25 2009 Frederic Crozat <fcrozat@mandriva.com> 8.97-6mdv2010.0
+ Revision: 421192
- Fix shutdown which could be blocked by plymouthd (Mdv bug #53051)
- Ensure plymouthd is stopped if started from initrd but splash isn't on cmdline
- Fix message in runlevel 0 and 6 hidden when no framebuffer is available but plymouth is enabled (Mdv bug #53110)

* Wed Aug 19 2009 Frederic Crozat <fcrozat@mandriva.com> 8.97-5mdv2010.0
+ Revision: 418132
- Send text message to plymouth for boot / reboot / shutdown

* Mon Aug 17 2009 Frederic Crozat <fcrozat@mandriva.com> 8.97-4mdv2010.0
+ Revision: 417398
- Fix speedboot broken by plymouth support
- Hide plymouth client output

* Mon Aug 17 2009 Frederic Crozat <fcrozat@mandriva.com> 8.97-3mdv2010.0
+ Revision: 417226
- Replace obsolete --retry-failed with --type=failed for udevadm settle call

* Thu Aug 13 2009 Frederic Crozat <fcrozat@mandriva.com> 8.97-2mdv2010.0
+ Revision: 416089
- Improve plymouth support

* Wed Aug 12 2009 Frederic Crozat <fcrozat@mandriva.com> 8.97-1mdv2010.0
+ Revision: 415626
- Release 8.97

* Tue Jul 28 2009 Eugeni Dodonov <eugeni@mandriva.com> 8.88-26mdv2010.0
+ Revision: 402779
- Prevent partial wireless key disclosure when wireless password contains spaces and is of certain length.
- Removed redefinition of action() routine in halt script (#52324)
- Unify handling of RedHat-style and Mandriva-style ifcfg files.
- Do not configure CRDA twice on boot.
- Properly support TMPDIR configuration from SECURE_TMP msec variable.

* Tue Jun 30 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-25mdv2010.0
+ Revision: 391025
- do not use wc to check for netprofiles (Mdv bug #51902, patch from Pascal Terjan)
- Add support for created TUN/TAP devices on the fly (Mdv bug #51964)
- Stop crypto devices before LVM (Mdv bug #51951)

* Fri Jun 26 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-24mdv2010.0
+ Revision: 389408
- improvement for readahead : early and later readhead are now blocking calls

* Wed Jun 24 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-23mdv2010.0
+ Revision: 388885
- Fix many speedboot issues :
 - disable speedboot when netprofile needs to be manually selected
 - disable speedboot on the fly when /etc/crypttab exists
 - fix status not being updated when using kdm
 - disable speedboot in failsafe mode
 - disable speedboot only when MD RAID / LVM volumes are detected
 - do not disable speedboot when quota is installed
- hide readahead error message

  + Eugeni Dodonov <eugeni@mandriva.com>
    - Added correct upstream url.
    - Corrected initscripts URL.

* Tue May 05 2009 Eugeni Dodonov <eugeni@mandriva.com> 8.88-22mdv2010.0
+ Revision: 372160
- Automatically detecting screen width to fit long messages (#16509)
- Updated network-scripts to work with bash-4.0 (#50511)

* Wed Apr 22 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-21mdv2009.1
+ Revision: 368741
- Fix usleep value for usb_storage timeout

* Wed Apr 22 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-20mdv2009.1
+ Revision: 368725
- speedboot: Load usb controller in first boot phase and ensure usb_storage module is loaded before waiting for usb storage devices to land (Mdv bug #50179
- rc.d/init.d/halt: Prevent "Sending all processes the KILL signal [Failed]" error (#45059)

* Tue Apr 21 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-19mdv2009.1
+ Revision: 368556
- load acpi in first pass in speedboot mode, fix clock timezone in syslog (Mdv bug #49513)-
- ensure usb keyboard is available under speedboot for single user rescue login
- ensure splashy is killed correctly if dropping to single user login (for fsck)
- Restrict agp module load to pci system (speedboot)
- put back udev in non-startup mode after latest udev settle (speedboot)

* Thu Apr 16 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-18mdv2009.1
+ Revision: 367749
- Enable back hdparm in speedboot mode, run it in parallel (both in speedboot and standard mode)
- remove obsolete libsafe support
- Add support for system-wide wireless ruglartory domain (Eugeni) (Mdv bug #49982, #49983, #49171)
- Fix usb-storage detection (Mdv bug #49474)
- Drop specific support for firewire stage, it should work with udev out of the box (and was broken for several releases).
- Translation updates
- Improve network-up logic (Mdv bug #49702)
- Fix ifup-ppp syntax error (Mdv bug #49942)

* Wed Apr 08 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-17mdv2009.1
+ Revision: 365193
- improve translations
- no longer limit udev child numbers, fix DRI being disabled in speedboot (Mdv bug #49490)

* Thu Apr 02 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-16mdv2009.1
+ Revision: 363589
- translations updates
- speedboot is not in automatic mode : it will try to enable itself if system can support it, or disable automatically in case of failure

* Fri Mar 27 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-15mdv2009.1
+ Revision: 361663
- fix detection of runlevel for usage in speedboot and stop splashy very early when starting in single user runlevel (me and eugeni)
- disable speedboot when runlevel is not 5
- disable speedboot when booting on a new kernel version for the first time
- disable speedboot when network authentication is enabled
- flag critical path when speedboot shouldn't be enabled (for speedboot auto-enabling, work in progress, not ready yet)
- add ypbind / winbkind and ldpa to network-auth dependencies (Eugeni)
- accept booting after some fsck errors like missing disk (Mdv bug #47242) (pterjan)
- cleanup rc.sysinit
- ensure /proc is mounted before reading /proc/cmdline (blino)

* Thu Mar 26 2009 Eugeni Dodonov <eugeni@mandriva.com> 8.88-14mdv2009.1
+ Revision: 361229
- Properly killing splashy when going to single-user mode.

* Tue Mar 24 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-13mdv2009.1
+ Revision: 360878
- Fix text not being displayed in splashy when booting

* Mon Mar 23 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-12mdv2009.1
+ Revision: 360729
- Enable readahead in speedboot mode
- Don't process some udev events twice in speedboot mode

* Thu Mar 19 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-11mdv2009.1
+ Revision: 358089
- Various speedboot fixes :
 - fix guest support under Virtualbox (Mdv bug #47726)
 - fix module preloading (Mdv bug #47974)
 - fix keyboard configuration in X with speedboot (Mdv bug #47638)
 - remove hardcoded delay after starting X server

* Wed Mar 18 2009 Eugeni Dodonov <eugeni@mandriva.com> 8.88-10mdv2009.1
+ Revision: 357493
- Fixed typo (missing white space).
- Added support for CRDA regulatory domains (#47324).

* Mon Mar 16 2009 Eugeni Dodonov <eugeni@mandriva.com> 8.88-9mdv2009.1
+ Revision: 356214
- Stopping splashy when going to single-user mode (#46169).
- Suggesting portreserve via ShouldStart in network-up.
- Support hdparm parameters for sd* devices (#45746).
- Stopping splashy when asking for LUKS password (#43325).

* Tue Feb 10 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-8mdv2009.1
+ Revision: 339180
- Ensure /proc/bus/usb is mounted in speedboot mode
- Disable fastboot mode when using speedboot : fsck is done in speedboot mode now

* Tue Feb 10 2009 Eugeni Dodonov <eugeni@mandriva.com> 8.88-7mdv2009.1
+ Revision: 339054
- Do not rely on plymouth for asking for LUKS partition passwords (#47670)
- Do not enable comgt for ADSL/xDSL connections (#47673)

* Fri Feb 06 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-6mdv2009.1
+ Revision: 338098
- Trigger block subsystem udev events early in speedboot mode (Mdv bug #47607)

* Thu Feb 05 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-5mdv2009.1
+ Revision: 337917
- Add support for runlevel 7, acting as runlevel S
- Speedboot, phase 1, implemented

* Wed Feb 04 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-4mdv2009.1
+ Revision: 337494
- Fix mismerge in rc.sysinit

* Wed Feb 04 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-3mdv2009.1
+ Revision: 337474
- package RH ChangeLog too
- mandriva_everytime :
    Don't handle supermount anymore, don't create /var/log/dmesg twice
- rc.sysinit : Cleanup obsolete stuff
    -ensure cmdline is set before using it
    -mount devpts / shm unconditionnaly
    -no longer load sound module (let udev do the job)
    -no longer call devlabel (no longer exist)
    -no longer modprobe aes (module no longer exist)
    -no longer remove rpm __db* at startup (rpm is autocleaning itself now)
    -no longer remove some temporary files twice
    -remove duplicate work for encrypted swap
    -merge back some stuff from RH initscript (to ease merge)
    -cache uname -r result

* Fri Jan 23 2009 Eugeni Dodonov <eugeni@mandriva.com> 8.88-2mdv2009.1
+ Revision: 333037
- Do not kill xsupplicant in ifdown-eth, as it could still be in use (#47052).

* Thu Jan 22 2009 Frederic Crozat <fcrozat@mandriva.com> 8.88-1mdv2009.1
+ Revision: 332568
- Release 8.88

* Fri Dec 19 2008 Olivier Blin <oblin@mandriva.com> 8.81-9mdv2009.1
+ Revision: 316078
- use Patch0 instead of Patch for new rpm

  + Frederic Crozat <fcrozat@mandriva.com>
    - Update dm initscript to start after hald

* Wed Nov 26 2008 Olivier Blin <oblin@mandriva.com> 8.81-8mdv2009.1
+ Revision: 307154
- add support for ATM bridging (for pppoe over USB modems, #35797)
- do not source 10lang.sh twice, it is useless for autologin

* Tue Sep 30 2008 Olivier Blin <oblin@mandriva.com> 8.81-7mdv2009.0
+ Revision: 290076
- dm service:
  o require messagebus instead of consolekit (dbus now spawns consolekit)
  o harddrake and dkms are not services anymore, do not soft-require them

* Mon Sep 29 2008 Olivier Blin <oblin@mandriva.com> 8.81-6mdv2009.0
+ Revision: 289231
- add support for readahead / readahead-collector early at boot time
  (from Frederic Crozat)

* Tue Sep 23 2008 Olivier Blin <oblin@mandriva.com> 8.81-5mdv2009.0
+ Revision: 287633
- check that /proc/cmdline exists before checking for splash inside
  (to hide error messages at One shutdown)
- rc.modules:
  o use modprobe -a to run modprobe one time only
  o support modprobedebug debug option (#28212)
  o do not hide modprobe stdout
  o drop 2.4 modules support (removes one more modprobe call)
  o use full path for modprobe

* Sat Sep 20 2008 Olivier Blin <oblin@mandriva.com> 8.81-4mdv2009.0
+ Revision: 286079
- implement $PERSISTENT_DHCLIENT that causes dhclient to be run in
  persistent mode, i.e. not giving up after one try to get an IP
  address (ported from upstream, by Anssi)

* Fri Sep 19 2008 Olivier Blin <oblin@mandriva.com> 8.81-3mdv2009.0
+ Revision: 285992
- start dkms and harddrake in mandrake_everytime
  (faster than running them in parallel init)
- load usb-storage module very early so that the usb-stor-scan process
  gets a chance to run in background sooner, not to block boot waiting
  for it later (thanks to Frederic Crozat for the debugging)
- make partmon configurable in /etc/sysconfig/partmon (#40625)
- fix improper quoting in 10tmpdir.sh (from vdanen, #40256)

* Tue Sep 02 2008 Olivier Blin <oblin@mandriva.com> 8.81-2mdv2009.0
+ Revision: 279131
- network-up: do not incorrectly wait for DNS to be set if not needed
  (patch from AAW, #42687)

* Mon Sep 01 2008 Olivier Blin <oblin@mandriva.com> 8.81-1mdv2009.0
+ Revision: 278334
- 8.81

* Tue Aug 19 2008 Olivier Blin <oblin@mandriva.com> 8.80-3mdv2009.0
+ Revision: 273671
- add network-auth meta-service that requires network to be up
  (to be enabled when auth requires network)
- dm: depend on network-auth instead of network-up
  (not to slow down boot when auth does not require network)
- do not follow symlinks when cleaning /var/lock and /var/run
  (breaks vserver)

* Fri Aug 08 2008 Olivier Blin <oblin@mandriva.com> 8.80-2mdv2009.0
+ Revision: 267991
- do not try to unmount mountpoints in /live at halt or when unmounting loopbacks

* Wed Aug 06 2008 Olivier Blin <oblin@mandriva.com> 8.80-1mdv2009.0
+ Revision: 264128
- fix group of debugmode package
- 8.80
- build without upstart
- do not create /etc/sysconfig/networking/tmp
- do not link /etc/init.d, it's done in chkconfig
- do not make ifcfg-lo a symlink to old networking directory
- do not load sysctl conf twice
- do not set loglevel twice
- fix ip route syntax (#42503)

* Fri Aug 01 2008 Olivier Blin <oblin@mandriva.com> 8.63-15mdv2009.0
+ Revision: 259573
- run wpa_cli reassociate if WIRELESS_WPA_REASSOCIATE is "yes"
  (for rt61pci)
- add more splash steps during shutdown

* Tue Jul 29 2008 Olivier Blin <oblin@mandriva.com> 8.63-14mdv2009.0
+ Revision: 252732
- allow splash to be enabled at shutdown
- fix checking that fb0 is present (by using sysfs)

* Fri Jul 25 2008 Olivier Blin <oblin@mandriva.com> 8.63-13mdv2009.0
+ Revision: 249732
- network-up: wait for DNS changes to be propagated by resolvconf if
  needed (thanks to Guillaume Rousse)
- check that splashy is available with "splashy_update test"
  (a zombie process might still live for a while if splashy is
  terminated from initrd)

* Wed Jul 23 2008 Olivier Blin <oblin@mandriva.com> 8.63-12mdv2009.0
+ Revision: 243732
- allow not to kill pids contained in /var/run/sendsigs.omit
  (inspired by Debian, to be used by splashy)
- detect splashy
- do not create fb0, this will be done in initrd
- avoid tty to be corrupted by splashy (from debian initscript)
- do not start brltty if BRLTTY is set to "no" in /etc/sysconfig/init
- prefdm (ander): quote the argument $dm since the preferred window
  manager may contain whitespace in its name (i.e. KDM 3)

* Fri Jun 20 2008 Pixel <pixel@mandriva.com> 8.63-10mdv2009.0
+ Revision: 227382
- lookupdm: /etc/X11/dm.d is now /usr/share/X11/dm.d

* Tue Jun 03 2008 Olivier Blin <oblin@mandriva.com> 8.63-9mdv2009.0
+ Revision: 214498
- ppp connections:
  o do not delete random route if there is no route matching a ppp
    interface that is brought up
  o use multipledefaultroutes option to add a default route for the
    ppp connection even if a default route already exists
    (and conflicts with pppd <= 2.4.4-3mdv2008.1)
  o set PIN code if needed when bringing ppp devices up (#34940, #40531)
- add ifup/ifdown scripts for hso devices (using custom AT_OWAN commands)
- retry failed udev events after local filesystems are mounted read-write
  (useful for rules creating network ifcfg files)

* Tue May 06 2008 Olivier Blin <oblin@mandriva.com> 8.63-8mdv2009.0
+ Revision: 202422
- init splash after font is reset (to make splash text messages
  reappear, #38882)
- create /dev/fb0 before splash is initialized (#38338)
- make sure resolvconf is available before network service is stopped
  (for cleaner stop of network-related services)

* Thu Apr 03 2008 Olivier Blin <oblin@mandriva.com> 8.63-7mdv2008.1
+ Revision: 192200
- do not use DNS* variables from config file if PEERDNS is true and
  BOOTPROTO is dhcp, this is handled by dhcp clients (#39312)
  (still use DNS* if RESOLV_MODS is true)
- support new WIRELESS_ENC_MODE variable (for open/restricted, to help
  fixing #26025)
- run ifplugd with -I by default (so that it does not abort when
  ifup/ifdown/dhclient fails)
- do not allow to run wpa_supplicant twice for the same interface,
  wpa_supplicant deauthenticate the connection when it fails (#38565)
- wait for wireless interfaces associated to an access point (#36964)
- do not add incorrect -D option for dhcpcd
- mount /dev/pts and /dev/shm after /dev is mounted by udev (so that
  /dev/pts gets correctly mounted when not using initrd, #30866)
- enable netfs/netconsole/dm services after network-up in post and
  preun (from Anssi)
- allow to display netfs status if network is disabled
  (from Pascal Terjan, #24579)

* Tue Mar 25 2008 Olivier Blin <oblin@mandriva.com> 8.63-6mdv2008.1
+ Revision: 190051
- do not start hclcollector in mandrake_firstime anymore, will be done by drakfirsttime (#39259)

* Fri Mar 21 2008 Olivier Blin <oblin@mandriva.com> 8.63-5mdv2008.1
+ Revision: 189326
- do not require messagebus in network service (it looks like network
  has to be up when dbus is started, with pam_ldap)
- export LC_ALL and LANG instead of running lang.sh for ntfs-3g mount
  (#38880)
- fix console mode setup in lang scripts when charset is not UTF-8
  (from Herton, #35082)
- mdv-network-event: do not check for /var/run/dbus/system_bus_socket,
  just hide errors
- run /sbin/halt.pre if present before umounting filesystems in
  /etc/init.d/halt

* Mon Mar 10 2008 Olivier Blin <oblin@mandriva.com> 8.63-4mdv2008.1
+ Revision: 183583
- export locale when mounting local filesystem (for ntfs-3g, #32436)
- do not check / if already rw (for example with unionfs)
- remove /tmp/esd-<uid> and /tmp/pulse-* directories at startup (fcrozat)

* Thu Feb 21 2008 Olivier Blin <oblin@mandriva.com> 8.63-3mdv2008.1
+ Revision: 173656
- keep UUID of swap partitions when resuming from hibernation (#37915)
- require util-linux-ng >= 2.13.1-4mdv2008.1 for mkswap -U <uuid> support

* Mon Feb 18 2008 Olivier Blin <oblin@mandriva.com> 8.63-2mdv2008.1
+ Revision: 171866
- rc.sysinit:
  o don't source /etc/sysconfig/init (already done by /etc/init.d/functions)
  o mount /proc/bus/usb before udev is started
  o remove duplicate pam_console reset
  o reduce diff with RH by moving quota and crypto code around

* Fri Feb 08 2008 Olivier Blin <oblin@mandriva.com> 8.63-1mdv2008.1
+ Revision: 163839
- 8.63
- raid is not enabled in rc.sysinit anymore, but in udev rules from the mdadm package
- clock is now initialized with udev rules
- drop EVMS support and duplicate LVM2 activation
- do not require bootloader-utils anymore

* Thu Jan 17 2008 Olivier Blin <oblin@mandriva.com> 8.60-2mdv2008.1
+ Revision: 154214
- conflicts with lsb-core < 3.1-15mdv2008.1 (/etc/networks has been moved in initscripts)
- set MIN_LINK_DETECTION_DELAY (to zero)
- do not make profile scripts executable
  (based on input from Guillaume Rousse)
- prefix inputrc and tmpdir profile scripts with a level number

* Tue Jan 15 2008 Olivier Blin <oblin@mandriva.com> 8.60-1mdv2008.1
+ Revision: 153094
- 8.60
- remove default MIN_LINK_DETECTION_DELAY (to catch buggy drivers)
- add support for an optional /etc/rc.early.local file, to be run at
  the very start of rc.sysinit (suggested by Colin Guthrie)
- nfs-common should be started before netfs (Anssi)

* Wed Oct 03 2007 Olivier Blin <oblin@mandriva.com> 8.54-8mdv2008.0
+ Revision: 95267
- 8.54-8mdv
- update translations

* Thu Sep 27 2007 Olivier Blin <oblin@mandriva.com> 8.54-7mdv2008.0
+ Revision: 93319
- fix regexps with non-working obsoleted syntax
  (from Nicolas Vigier, thanks to Anssi Hannula, #32501)
- add should-start/stop for messagebus, since ifup/ifdown run mdv-network-event (#34076)
- add explicit provides in netconsole initscript
- more typo fixes (from Jose Da Silva)

* Thu Sep 20 2007 Olivier Blin <oblin@mandriva.com> 8.54-6mdv2008.0
+ Revision: 91318
- 8.54-6mdv
- ifdown: do not kill wpa_supplicant when link gets down
  (#31904, thanks to Anssi Hannula)
- ifup/ifdown: send D-Bus events when interfaces get up/down
- mandrake_firstime: start hclcollector in mandrake_firstime
- rc.sysinit: delete core files located in gdm directory, at startup
  (#28166, from Frederic Crozat)
- netconsole: add LSB header (from Goetz Waschk)
- service: fix typos and do not exceed 80 chars (from Jose Da Silva)
- lang.sh: move LANGUAGE redefine (CONSOLE_NOT_LOCALIZED) later, so
  that it will not overrided by *.UTF-8 step (from Funda Wang)
- po: use local mirror to extract init.d files (from Funda Wang)
- remove obsolete usb service (2.4 specific)

* Mon Aug 20 2007 Olivier Blin <oblin@mandriva.com> 8.54-5mdv2008.0
+ Revision: 68050
- really use MIN_LINK_DETECTION_DELAY (#31864, thanks to Emmanuel Blindauer for the debugging)
- add dependency on consolekit (#32555, from fcrozat)

* Fri Aug 10 2007 Olivier Blin <oblin@mandriva.com> 8.54-4mdv2008.0
+ Revision: 61663
- disable supermount on upgrade, it's not supported anymore in our kernels (from Pixel)
- fix locking in udev rules (from Andrey Borzenkov, #32281)
- fix UTF-8 support by removing mandrake_consmap since we use kdb (from Herton Ronaldo Krzesinski, #32256)
- remove duplicate "Press 'I' to enter interactive startup." phase
- start brltty after udev so that vcsa device nodes are created (thanks to fcrozat)

* Wed Aug 01 2007 Olivier Blin <oblin@mandriva.com> 8.54-3mdv2008.0
+ Revision: 57809
- remove setsysfont, use kbd and update doc (from Herton Ronaldo Krzesinski)
- modprobe IDE controller at system start (#32150)

* Sat Jul 07 2007 Olivier Blin <oblin@mandriva.com> 8.54-2mdv2008.0
+ Revision: 49354
- from Ademar:
  add xfs to dm's 'Should-Start:', since it's still supported,
  just not enabled by default (thanks Blino for spotting this)

* Fri Jul 06 2007 Olivier Blin <oblin@mandriva.com> 8.54-1mdv2008.0
+ Revision: 48955
- 8.54
- set LANGUAGE and LC_ALL for prcsys (#27663)
- from Herton: small typo fix in setsysfont script
- from Ademar: xfs is not needed by dm anymore,
  xorg now uses fontpath.d and xfs is deprecated (see #31756)
- exclude supermount on all sparc archs (Per Oyvind Karlsen, #30622)

* Tue May 01 2007 Olivier Blin <oblin@mandriva.com> 8.53-1mdv2008.0
+ Revision: 19999
- 8.53


* Sat Apr 07 2007 Olivier Blin <oblin@mandriva.com> 8.51-7mdv2007.1
+ Revision: 151214
- use start_udev instead of /etc/init.d/udev
- drop obsolete /lib/udev/devices support
- drop 2.4 support for usb/ieee1394 controllers hotplug

* Wed Apr 04 2007 Olivier Blin <oblin@mandriva.com> 8.51-6mdv2007.1
+ Revision: 150515
- do not make the network service require shorewall (revert changes introduced in 3mdv, #30095)

* Tue Apr 03 2007 Olivier Blin <oblin@mandriva.com> 8.51-5mdv2007.1
+ Revision: 150449
- setup non-root dmraid sets (#30064)

* Thu Mar 29 2007 Olivier Blin <oblin@mandriva.com> 8.51-4mdv2007.1
+ Revision: 149649
- fix link detection when ifplugstatus is not reliable (leeloo-approved)

* Tue Mar 27 2007 Olivier Blin <oblin@mandriva.com> 8.51-3mdv2007.1
+ Revision: 149047
- network service:
  o should start slmodemd
  o require shorewall instead of firewall
  o remove obsolete pcmcia require
  o remove obosolete ipw3945d require
- conflicts with old suspend-scripts version

* Fri Mar 23 2007 Olivier Blin <oblin@mandriva.com> 8.51-2mdv2007.1
+ Revision: 148235
- do not conflict with suspend-scripts to ease upgrade, pm-utils will take care of the proper package ordering

* Mon Mar 12 2007 Olivier Blin <oblin@mandriva.com> 8.51-1mdv2007.1
+ Revision: 141477
- 8.51 (sync with RedHat)
- rc.sysinit: avoid progress bar to go reverse
- drop incorrect Roaming wireless mode, rely on WIRELESS_WPA_DRIVER instead
- check NEEDHOSTNAME value, not only its definedness (for pump and dhcpcd)
- check for NOZEROCONF value, not only its definedness
- PEERGATEWAY support (#20806)
- netfs should have portmap during stop (from Giuseppe Ghibo)
- network service should start ipw3945d
- dm service should start lircmd (#20771)

* Wed Jan 24 2007 Olivier Blin <oblin@mandriva.com> 8.48-8mdv2007.1
+ Revision: 113016
- hibernate-cleanup script:
  o sync with upstream suspend2 project
  o handle user-space swsusp signature (from Andrey Borzenkov, #28292)
  o swap labels support (from Andrey Borzenkov, #28292)
- po files: adapted to plural-forms (Pablo)

* Sat Jan 20 2007 Olivier Blin <oblin@mandriva.com> 8.48-7mdv2007.1
+ Revision: 111144
- make the rc.local initscript LSB compliant (#24227)

* Sat Jan 20 2007 Olivier Blin <oblin@mandriva.com> 8.48-6mdv2007.1
+ Revision: 111142
- do not wrongly provide the local_fs system facility in netfs service (#25755)
- do not enforce portmap dependency in netfs service (#25668)
- allow the netfs service to mount NFS filesystems even if portmap is not started
- add a MIN_LINK_DETECTION_DELAY option, defaulting to 6 seconds (for network-up service, #28078)
- do not override NETWORKDELAY if set (network-up service)

* Thu Jan 18 2007 Olivier Blin <oblin@mandriva.com> 8.48-5mdv2007.1
+ Revision: 110431
- move hibernate-cleanup.sh from suspend-scripts to initscripts

* Fri Jan 12 2007 Olivier Blin <oblin@mandriva.com> 8.48-4mdv2007.1
+ Revision: 108108
- add a clear_resolv_conf function in network-functions

* Tue Jan 02 2007 Olivier Blin <oblin@mandriva.com> 8.48-3mdv2007.1
+ Revision: 103352
- resolvconf support

* Thu Dec 28 2006 Olivier Blin <oblin@mandriva.com> 8.48-2mdv2007.1
+ Revision: 102435
- add lsb init-functions (#27475)

* Thu Dec 28 2006 Olivier Blin <oblin@mandriva.com> 8.48-1mdv2007.1
+ Revision: 102408
- 8.48
- Import initscripts

* Wed Sep 20 2006 Olivier Blin <oblin@mandriva.com> 8.38-7mdv2007.0
-  enable swap automatically if configured so only (fix merge with rh8.38, #25908)

* Sun Sep 17 2006 Olivier Blin <oblin@mandriva.com> 8.38-6mdv2007.0
- don't trust link beat reporting before the interface delay specified in
  LINK_DETECTION_DELAY (#18986)
- add network as Required-Stop in network-up service

* Thu Sep 14 2006 Olivier Blin <oblin@mandriva.com> 8.38-5mdv2007.0
- mount /proc/bus/usb if needed (#25340)
- start hibernate-cleanup.sh before swap is enabled (#25595)
- delay font loading if /usr/bin/locale can't be found (#24299)
- reset i18n settings when font is delayed (#24299)

* Fri Sep 08 2006 Olivier Blin <oblin@mandriva.com> 8.38-4mdv2007.0
- network-up:
  o don't check non-existent devices
  o check link down on correct device
- from Frederic Crozat:
  o Don't load visor module anymore
  o reduce tmp cleanup

* Thu Sep 07 2006 Olivier Blin <oblin@mandriva.com> 8.38-3mdv2007.0
- add a network-up service that waits for network to be up (using NETWORKDELAY)
  and provides the $network system facility (#18986)
- use Mandriva Linux as distribution name in inittab(#25260)

* Sat Aug 26 2006 Olivier Blin <oblin@mandriva.com> 8.38-2mdv2007.0
- revert to previous poweroff behaviour (#24432)
- fix network service status (thanks to Loic Baudry, #24344)

* Fri Aug 18 2006 Olivier Blin <oblin@mandriva.com> 8.38-1mdv2007.0
- 8.38
- vpn-start: vpnc support
- add some documentation about Mandriva DHCP options (#14921)
- always source autofsck settings, for AUTOFSCK_CRYPTO_TIMEOUT (#16029)
- don't unmount /dev/root* but only /dev/root when halting system (#21469)
- remove X11R6 path in /etc/init.d/functions (#22951)
- require dmsetup (#24187)
- require prcsys and drop prcsys source code
- udev_copy_temp_rules is now in /sbin (#23196)

* Fri Aug 04 2006 Olivier Blin <oblin@mandriva.com> 8.35-2mdv2007.0
-  add vpn helpers (vpn-start, vpn-stop, and ifup.d/ifdown.d scripts)

* Fri Jul 21 2006 Olivier Blin <oblin@mandriva.com> 8.35-1mdv2007.0
- 8.35
- add mdv-network-event helper and use it in ifup-eth

* Sat Jul 01 2006 Olivier Blin <oblin@mandriva.com> 8.34-3mdv2007.0
- use killproc to kill dm service (from AAW, #23438)
- use action() instead of runcmd() (#23440)

* Wed Jun 28 2006 Olivier Blin <oblin@mandriva.com> 8.34-2mdv2007.0
- output dm pid in /var/run/dm.pid to fix dm service status (#19321)
- remove hardcoded X11R6 path in prefdm
- add missing newline characters in some status() messages

* Sat Jun 24 2006 Olivier Blin <oblin@mandriva.com> 8.34-1mdv2007.0
- merge with rh 8.34
- sysctl.conf: set dev.cdrom.autoclose to 1
  (as supermount isn't used anymore for CD-Roms)
- fix ip-up merge with rh8.33 (define REALDEVICE correctly)

* Wed May 24 2006 Olivier Blin <oblin@mandriva.com> 8.33-4mdk
- rc.modules: add modprobe.preload.d and modules.d support
- rc.modules: use "logger -t $0" instead of "initlog -s"
- (painfully) move to SVN
- fix prereq (tv)

* Tue May 16 2006 Olivier Blin <oblin@mandriva.com> 8.33-3mdk
- copy udev rules created while root was read-only (Andrey Borzenkov)
- bump udev requires

* Fri May 05 2006 Olivier Blin <oblin@mandriva.com> 8.33-2mdk
- handle /fsckoptions in rc.sysinit (should have been merged years ago)
- really use fsck return code in rc.sysinit (#22276)
- run ifplugd -k -W only once (#22278)
- unimplement --version (Manuel López-Ibáñez, #20031)
- fix typo in netfs service (use Required-Stop)

* Thu May 04 2006 Olivier Blin <oblin@mandriva.com> 8.33-1mdk
- merge with rh 8.33
- use ifup-post to update resolv.conf when possible
  (so that DNS servers are correctly ordered)
- revert wrong fix for vconfig path (in ifup and ifdown, #21849)
- don't delete ppp peers file for ADSL connections (#21506)
- don't run update_boot_stage (#21819)
- remove some kernel 2.2 support in rc.sysinit

* Tue Mar 28 2006 Olivier Blin <oblin@mandriva.com> 8.31.2-1mdk
- merge with rh 8.31.2

* Thu Feb 09 2006 Olivier Blin <oblin@mandriva.com> 8.26-1mdk
- merge with rh 8.26
- install rc.modules in /etc (#21058)
- fix endless loop in change_resolv_conf (Michael Reinsch, #21059)
- use su instead of runuser (#21063)
- sysconfig.txt: fix some typos

* Mon Feb 06 2006 Olivier Blin <oblin@mandriva.com> 8.23-1mdk
- merge with rh 8.23:
  o split ifup-eth out of ifup
  o make ipv6 stuff almost vanilla
  o add /var/log/btmp
  o remove fsck prompt in rc.sysinit
  o remove rawdevices service
  o remove minilogd
- ifup-eth:
 o simplify ifplugstatus usage
 o load wireless settings even if wpa_supplicant is used (#20398)

* Thu Jan 26 2006 Olivier Blin <oblin@mandriva.com> 7.61.1-59mdk
- enable pinit by default (nopinit disables it)
- print "is an LSB script" messages in test mode only

* Wed Jan 25 2006 Olivier Blin <oblin@mandriva.com> 7.61.1-58mdk
- initialize /dev contents from /lib/udev/devices (Andrey Borzenkov, #20648)
- try to remove cups run files (#20303)

* Sat Jan 14 2006 Olivier Blin <oblin@mandriva.com> 7.61.1-57mdk
- prcsys: fix typo in LSB message (Dick Gevers, #20626)
- dm:
  o should start acpid (or else X will steal /proc/acpi/event)
  o should start dkms (nvidia/ati drivers)
- fix build on sparc by including obsolete usb service (Per Øyvind Karlsen)
- resurrect missing changelog entry from Thierry Vignaud

* Mon Jan 09 2006 Olivier Blin <oblin@mandriva.com> 7.61.1-56mdk
- from Couriousous: add test mode in prcsys (--test),
  don't execute script, only show run order
- from Thierry Vignaud: enable to disable EVMS either by passing
  "noevms" on the kernel command line or by adding 'NOEVMS="no"' into
  /etc/sysconfig/init

* Sun Jan 08 2006 Olivier Blin <oblin@mandriva.com> 7.61.1-55mdk
- prcsys:
  o misc minor fixes (don't segfault, don't rm /dev/null)
  o LSB tags support (from Couriousous)
- convert X-Parallel-* tags to LSB

* Mon Jan 02 2006 Olivier Blin <oblin@mandriva.com> 7.61.1-54mdk
- rc.sysinit: check for /dev/.udev
- from Couriousous:
  o prcsys: add X-Parallel-Init support
  o add parallel init support in dm, partmon
  o network: require all firewall scripts to be started

* Sat Dec 31 2005 Olivier Blin <oblin@mandriva.com> 7.61.1-53mdk
- rc.sysinit: fix incorrect use of the local keyword

* Sat Dec 31 2005 Olivier Blin <oblin@mandriva.com> 7.61.1-52mdk
- rc.sysinit: wait for usb and firewire storage scanning processes to
  finish before initializing device-mapper/lvm
- initial parallel-init support (from Couriousous, with minor adjustments)
- mkrel

* Tue Oct 04 2005 Olivier Blin <oblin@mandriva.com> 7.61.1-51mdk
- use /dev tmpfs from initrd again
- check if consolechars is in /bin (Pablo)

* Tue Sep 20 2005 Frederic Lepied <flepied@mandriva.com> 7.61.1-50mdk
- updated translations
- sysctl.conf: don't provide a value for net.ipv4.ip_forward.

* Sat Sep 17 2005 Olivier Blin <oblin@mandriva.com> 7.61.1-49mdk
- ifdown:
  o wait for ifplugd to be killed
  o avoid SIOCGIFFLAGS usage when ifdown is run from hotplug
    (it triggers module loading)

* Tue Sep 13 2005 Frederic Lepied <flepied@mandriva.com> 7.61.1-48mdk
- updated translations
- fix %%post to use grep instead of fgrep (bug #18405)
- lang.sh: even in gdm, source $HOME/.i18n and /etc/sysconfig/i18n (bug #18230).

* Fri Sep 09 2005 Olivier Blin <oblin@mandrakesoft.com> 7.61.1-47mdk
- ifup: don't try to rename device according to HWADDR if no device
  exists, or else ifup will loop endlessly and block boot

* Wed Sep 07 2005 Frederic Lepied <flepied@mandriva.com> 7.61.1-46mdk
- really include my changes forgotten in 45mdk

* Tue Sep 06 2005 Olivier Blin <oblin@mandriva.com> 7.61.1-45mdk
- umount initrd after the udev service has copied the lvm/dmraid nodes
- from Frederic Lepied:
  o tmpdir.sh: better init of the SECURE_LEVEL
  o tmpdir.sh: default SECURE_LEVEL is 3
  o dm: discplay a carriage return after the message in stop action
    (bug #16293, Bruno Santos).

* Mon Sep 05 2005 Olivier Blin <oblin@mandriva.com> 7.61.1-44mdk
- network scripts (Andrey Borzenkov):
  o really handle wireless.d files in roaming mode (#18211)
  o ifup-wireless: handle WIRELESS_IWPRIV with spaces (#18207)
- tmpdir.sh (Frederic Lepied): bourne shell compatible fix

* Thu Sep 01 2005 Pixel <pixel@mandriva.com> 7.61.1-43mdk
- adapt inputrc.csh to new tcsh (bugzilla #17999)

* Wed Aug 31 2005 Olivier Blin <oblin@mandriva.com> 7.61.1-42mdk
- add /etc/sysconfig/network-scripts/wireless.d
- rc.sysinit: use udevstart to handle usb coldplug on 2.6 kernels
- ifup:
  o move dynamic config test after wireless.d sourcing, so that
    BOOTPROTO can actually be overriden (#17973, Michael Reinsch)
  o don't use hardcoded interface name in roaming mode
    (#17974, Michael Reinsch)
  o do not run wpa_supplicant again on association if ifplugd
    is used and WIRELESS_MODE != "Roaming" (#17989)
- ifup-wireless: don't forbid to set key before xsupplicant is run
- lang.sh (Pablo): fixed problem of LANGUAGE=C remaining when changing
   between X11 <-> console for the special cases when localization
   is not supported in one of the two but is on the other.

* Sat Aug 27 2005 Thierry Vignaud <tvignaud@mandriva.com> 7.61.1-41mdk
- do not keep initrd's /dev (thus fixing cciss support)

* Thu Aug 25 2005 Pixel <pixel@mandriva.com> 7.61.1-40mdk
- compress ChangeLog (to be smaller)

* Sat Aug 20 2005 Frederic Lepied <flepied@mandriva.com> 7.61.1-39mdk
- rc.sysinit, netfs: added suport for shfs (bug #15964)
- halt: fixed random-seed file name (bug #15889).

* Fri Aug 19 2005 Olivier Blin <oblin@mandriva.com> 7.61.1-38mdk
- allow to use the "daemon" parameter instead of "boot" in
  ifup/ifdown, so that daemons (ifplugd/wpa_supplicant) can be used
  even if ONBOOT=no
- allow wpa_supplicant to be used without roaming

* Fri Aug 12 2005 Flavio Bruno Leitner <flavio@mandriva.com> 7.61.1-37mdk
- changed requires from modutils to module-init-tools

* Tue Aug 09 2005 Frederic Lepied <flepied@mandriva.com> 7.61.1-36mdk
- fixed single user mode (bug #16823)

* Sat Aug 06 2005 Olivier Blin <oblin@mandriva.com> 7.61.1-35mdk
- handle wireless ESSIDs with spaces for wireless roaming

* Fri Aug 05 2005 Olivier Blin <oblin@mandriva.com> 7.61.1-34mdk
- no need to regenerate mozilla registry at firstboot anymore
  (Frederic Crozat)
- xsupplicant support in ifup-wireless (Arnaud de Lorbeau)
- add wireless roaming support
- start wpa_supplicant in ifup instead of ifup-wireless
  (start it at boot or if roaming is disabled)
- start ifplugd in ifup (with boot option) instead of network service
- don't delete route for interfaces related to an alias interface
  being shut down
- skip metric setting for alias interface

* Tue Jul 12 2005 Frederic Lepied <flepied@mandriva.com> 7.61.1-33mdk
- fix hotplug stuff wrt to network devices
- translation updates

* Tue Jul 05 2005 Frederic Lepied <flepied@mandriva.com> 7.61.1-32mdk
- netfs: fixed NFS shares are not mounted at boot (bug #16531).
- translation updates

* Sat Jun 18 2005 Frederic Lepied <flepied@mandriva.com> 7.61.1-31mdk
- rc.sysinit: Mandriva Linux
- updated translations: ms and nb
- mandrake_everytime: fix netprofile vs globetrotter (Thierry)

* Thu Jun 02 2005 Frederic Lepied <flepied@mandriva.com> 7.61.1-30mdk
- prefdm: fix dm variable for non standard display manager (littletux).

* Tue May 31 2005 Frederic Lepied <flepied@mandriva.com> 7.61.1-29mdk
- prefdm: use the right default values for looking up the display
  manager.
- mandrake/lookupdm: use NAME as the key to find the right entry
  instead of DISPLAYMANAGER.
- rc.d/init.d/network: fix net-pf-10 alias being rewritten at each
  boot (#16045) (Olivier Blin)

* Tue May 31 2005 Frederic Lepied <flepied@mandriva.com> 7.61.1-28mdk
- network-functions, ifup: fixed ethtool path

* Tue May 31 2005 Frederic Lepied <flepied@mandriva.com> 7.61.1-27mdk
- update of translations
- use a modularized prefdm script to be able to provide new display
  managers easily (based on Loic Baudry's work).
- sysconfig/network-scripts/ifup-wireless: allow multi-line
  WIRELESS_IWPRIV variable (Olivier Blin).
- sysconfig/network-scripts/ifup: DVB support (Olivier Blin).
- rc.d/rc.sysinit: fix syntax error when nousb is used on the
  command line (David Faure).

* Tue Apr 05 2005 Olivier Blin <oblin@mandrakesoft.com> 7.61.1-26mdk
- ralink interfaces need to be up before performing iwconfig commands
- ATMARP protocol support, enabled if ATM_ADDR is defined (VCI.VPI),
  useful for modems using the atm kernel module (e.g. Speedtouch)
  and ISP using "RFC 1483 Routed VC MUX" (e.g. Free Degroupe)
- do not write empty net-pf-10 aliases
- change Mandrake in Mandrakelinux for the default theme (Warly)

* Wed Mar 23 2005 Warly <warly@mandrakesoft.com> 7.61.1-25mdk
- mandrake_everytime: do not use initlog in quiet mode for netprofiles (menu)
- rc.sysinig: check that /usr/bin/consolechars is available before 
  calling setsysfonts (bug #11054)
- rc.d/init.d/network: fix duplicate addition of aliases in modprobe.conf
  and correct a potential bug when NETWORKING_IPV6 is not set (blino)

* Tue Mar 22 2005 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-24mdk
- netfs, network: fixed nfs unmounting (Oden, bug #13677)
- mandrake_everytime: put the -depth argument of find at the right
place (J.A. Magallon, bug #13354).
- po updates: sk.
- rc.sysinit: o don't enable process accounting here (bug #13672).
              o removed duplicated code for setting hdparm options (bug #13677).

* Mon Mar 14 2005 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-23mdk
- /etc/rc.local must be a config file (bug #13553)
- requires ifmetric
- setsysfont, rc.d/rc.sysinit, rc.d/init.d/functions: added a
 get_locale_encoding function to rc.d/init.d/functions so that
 detection of locale encoding from init scripts is easier;
 simplified the font loading.	rewrite setsysfont script to better
 detect the locale, and to look first at /etc/sysconfig/console in
 all cases. (Pablo)
- rc.d/rc.local: put issue and issue.net stuff in mandrake_everytime.
- rc.d/init.d/network: handle net-pf-10 alias for respecting
 NETWORKING_IPV6 (Warly, bug #11896).
- po updates
- do not try to restart the no more existing random service (Thierry, #13426)

* Tue Feb 22 2005 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-22mdk
- requires udev
- ifup-ppp: do not detach ppp for modems (Olivier Blin)
- po updates
- rc.sysinit:
	o start EVMS if needed (bug #13634) (Thierry)
        o use udev instead of hotplug (thus fixing sysfs
	populating delays and delete/add serializing) (Thierry)
	o start udev very early while bootstrapping, thus
	fixing lost device nodes for lvm2 (bug #12046) (Thierry)
- rawdevices: workaround broken autoloading of raw driver (Thierry).

* Thu Feb 10 2005 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-21mdk
- init.d/rawdevices: workaround broken autoloading of raw
  driver. (Thierry)
- rc.sysinit: use udev instead of hotplug (thus fixing sysfs
  populating delays and delete/add serializing). (Thierry)
- po updates
- init.d/functions: force use of UTF-8 (OUTPUT_CHARSET=UTF-8)
for the bootsplash translations. (Pablo)
- Added Brazilian man files (Pablo)

* Wed Feb 02 2005 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-20mdk
- po updates
- no wait anymore for ifup result in network service when using ifplugd

* Tue Feb 01 2005 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-19mdk
- po updates
- mandrake/supermount: remove unhide from floppy options (Olivier
  Blin, bug #7336).
- rc.d/rc.sysinit: Michel Bouissou, bug #12771: - avoid activating
  encrypted swap partition directly handled by swapon.	- work with
  static crypto modules.  - keep the swap signature (4096 first
  bytes) when mounting an encrypted swap.
- rc.d/rc.sysinit: Don't apply hdparm on software RAID arrays that
  are in process of background resyncing (Michel Bouissou , bug
  - rc.d/init.d/network: use ifplugd on static address too (bug
  - rc.d/init.d/functions: fix translation errors for autofs
  (Guillaume Rousse, bug #12303).
- rc.d/rc.sysinit: fix untranslation of 3 first messages (#12507)
  by setting font and the like earlier (Thierry).
- rc.d/rc.sysinit: delete /var/run/xdmctl (bug #13155).
- sysconfig/network-scripts/ifup-wireless: added the POWER option
  to manage iwconfig power option (Brouard Nicolas).
- initscripts no more config files.

* Fri Dec 17 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-18mdk
- rc.d/rc.sysinit: be sure to create block devices in udev mode
  (Luca Berra)
- sysconfig/network-scripts/ifup-wireless: support for
  wpa_supplicant (Nicolas Chipaux)
- sysconfig/network-scripts/ifdown: kill wpa_supplicant for the
  interface too
- rc.d/rc.sysinit: fix udev check after switching from udev-030 to
  udev-046 (#12553)
- po updates: ku, br and ca

* Sat Oct 09 2004 Warly <warly@mandrakesoft.com> 7.61.1-17mdk
- revert Olivier change which breaks splash displaying at shutdown

* Fri Oct 01 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-16mdk
- don't try to mount /dev/pts twice (bug #11756)

* Thu Sep 30 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-15mdk
- rc.sysinit: modprobe scsi_hostadapter earlier to be able to use lvm
  on a second scsi controller (reported by Luca Berra)

* Thu Sep 30 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-14mdk
- rc.sysinit: fix init of /dev/tty[1-8]
- rc.sysinit: fix mount of /dev/pts and /dev/shm
- po updates

* Wed Sep 22 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-13mdk
- rc.d/init.d/functions: do not restore splash as silent if verbose
 mode was enabled very early (Olivier).
- po updates

* Wed Sep 22 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-12mdk
- setsysfont, rc.d/rc.sysinit: improved the way that the encoding
 of the console is guessed (bug #11147) (Pablo)
- po updates
- fix loading of st module (Luca Berra)
- fixed Continue in interactive startup (bug #10943)
- rc.sysinit: correct test for devfsd and add newline in the output
 (bug #11318)

* Tue Sep 14 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-11mdk
- po updates
- clean correctly dynamic desktop files

* Fri Sep 10 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-10mdk
- correctly add search directive in resolv.conf (bug #11317)
- don't use ttys when not available (bug #11314)

* Thu Sep 09 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-9mdk
- set TMP and TMPDIR to /tmp to have the same behaviour during boot and
after (request from Giuseppe)
- move /initrd/dev to /dev in udev mode and lazy umount /initrd
- po updates

* Thu Sep 09 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-8mdk
- rc.sysinit: fixed typo

* Wed Sep 08 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-7mdk
- it man pages
- po updates
- modprobe ide-cd and scsi_hostadapter

* Tue Sep 07 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-6mdk
- rc.d/rc.sysinit: handle udev in initrd (Luca Berra)
- lang.sh: export QT_IM_MODULE too since it's needed by
  Qt-immodule-20040819 (UTUMI Hirosi)
- po updates

* Thu Sep 02 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-5mdk
- rc.sysinit: LVM fixes for udev mode (Luca Bera)
- po updates

* Thu Sep 02 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-4mdk
- po updates and fixes
- do not override the default config file in adsl-stop, let it use its
/etc/ppp/pppoe.conf (Olivier)
- rc.sysinit: modprobe loop, aes and cryptoloop when needed
- rc.sysinit fixes from Luca Bera:
1) rework creation of device mapper control node so we don't depend on
nash.
2) mdadm is preferred over raidtools now, and empty configuration files
are ignored.
3) correctly activate lvm after raid.
4) mount other filesystem once, not twice.

* Fri Aug 27 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-3mdk
- usb: cold boot devices with hotplug rc script

* Tue Aug 24 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-2mdk
- rc.d/init.d/halt: remove sleep and exit in case of powerfail
(apcupsd). request from David Walser.
- ifup-ppp: fix default route removal (Olivier)
- ifup: fix loop when using HWADDR (bug #10851)
- po updates

* Wed Aug 18 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.61.1-1mdk
- merged with 7.61.1

* Wed Aug 18 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.06-54mdk
- rc.sysinit: cleanup dynamic files for KDE and GNOME
- init.d/functions: define locale when calling splash.sh (Pablo)
- rc.sysinit: fix crypto fs message (from Lubos Klokner)
- po updates
- ifup-ppp: delete default route only on the same interface
- ifup: ifmetric is called from ifup-post now
- mandrake_everytime: no need anymore to use /etc/sysconfig/network-scripts/noifup

* Sat Jul 31 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.06-53mdk
- ifup: call ifmetric if METRIC is set.

* Fri Jul 30 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.06-52mdk
- do not set hotplug to /bin/true anymore (bug #9289)
- ifup-ppp: detach pppd once the connection is established, thus
 avoiding to hang the boot process if a ppp connection is started at
 boot. (Olivier)
- ifup-ppp: fix pppoe startup (Thierry)
- po updates
- sysctl.conf: add a more meaningful comment to autoclose. (Warly)

* Fri Jun 25 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.06-51mdk
- modifications to be able to use the network service instead of the
  internet service for ADSL connections (Damien)
- po updates
- merged with 7.06-49.1.100mdk:
  - lang.csh, lang.sh: do not return when LC_SOURCED is set but only
   avoid sourcing the i18n file (anthill #919)
  - fixed ifdown-aliases (bug #9366)
  - rc.sysinit: use translated keys too during fsck question (bug #8024)
  - rc.sysinit: remove unneeded code for loopback filesystem check (Glenn Burkhardt) (bug #8698)
  - rc.sysinit: only check nousb on the command line to not start the usb service (bug #9830).

* Wed Jun 02 2004 Frederic Lepied <flepied@mandrakesoft.com> 7.06-50mdk
- sound services handled by the sound-scripts package now (Thierry)
- po: eo, ro, gl, eu, ky: updated po files (Pablo)
- mandrake/usb: get back to usbfs as speedtch kernel driver is now
 properly working with both 2.4 and 2.6 and needs it. (thanks to pump) (Damien)
- sysconfig/network-scripts/network-functions: adapt to ifplugd-0.24 (Thierry)
- rc.d/rc.local: If using the default logo it will use the mandrake
 logo instead :) (Per Øyvind Karlsen)

